Glycowork
================

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

![Analyzing glycans and their role in
biology](https://github.com/BojarLab/glycowork/workflows/CI/badge.svg)

<img src="./glycowork_badge_wo_bg.jpg" width="200" />

Glycans are a fundamental biological sequence, similar to DNA, RNA, or
proteins. Glycans are complex carbohydrates that can form branched
structures comprising monosaccharides and linkages as constituents.
Despite being conspicuously absent from most research, glycans are
ubiquitous in biology. They decorate most proteins and lipids and direct
the stability and functions of biomolecules, cells, and organisms. This
also makes glycans relevant to every human disease.

The analysis of glycans is made difficult by their nonlinearity and
their astounding diversity, given the large number of monosaccharides
and types of linkages. `Glycowork` is a Python package designed to
process and analyze glycan sequences, with a special emphasis on
glycan-focused data science and machine learning. Next to various
functions to work with glycans, `glycowork` also contains glycan data
that can be used for model training, motif comparisons, etc. Glycowork
uses human-readable IUPAC-condensed (e.g.,
`Neu5Ac(a2-3)Gal(b1-3)[Neu5Ac(a2-6)]GalNAc`) as a user-facing string
representation and monosaccharide-level graphs as a powerful
behind-the-scenes architecture.

If you use `glycowork` or any of our datasets in your project, please
cite [Thomes et al.,
2021](https://academic.oup.com/glycob/advance-article/doi/10.1093/glycob/cwab067/6311240).

The inspiration for `glycowork` can be found in [Bojar et al.,
2020](https://doi.org/10.1016/j.chom.2020.10.004) and [Burkholz et al.,
2021](https://pubmed.ncbi.nlm.nih.gov/34133929/). There, you can also
find examples of possible use cases for the functions in `glycowork`.

The full documentation for `glycowork` can be found here:
https://bojarlab.github.io/glycowork/

If you want to contribute to `glycowork`, the best place to start is to
read our [contribution
guidelines](https://github.com/BojarLab/glycowork/blob/master/CONTRIBUTING.md).

## Install

via pip: <br> `pip install glycowork` <br> `import glycowork`

alternative: <br>
`pip install git+https://github.com/BojarLab/glycowork.git` <br>
`import glycowork`

## Data & Models

`Glycowork` currently contains the following main datasets that are
freely available to everyone:

- **`df_glycan`**
  - contains \>51,500 unique glycan sequences, including labels such as
    \>33,000 species associations, \>9,500 tissue associations, and
    \>500 disease associations
- **`glycan_binding`**
  - contains \>550,000 protein-glycan binding interactions, from 1,392
    unique glycan-binding proteins

Additionally, we store these trained deep learning models for easy
usage, which can be retrieved with the `prep_model` function:

- **`LectinOracle`**
  - can be used to predict glycan-binding specificity of a protein,
    given its ESM-1b representation; from [Lundstrom et al.,
    2021](https://onlinelibrary.wiley.com/doi/10.1002/advs.202103807)
- **`LectinOracle_flex`**
  - operates the same as LectinOracle but can directly use the raw
    protein sequence as input (no ESM-1b representation required)
- **`SweetNet`**
  - a graph convolutional neural network trained to predict species from
    glycan, can be used to generate learned glycan representations; from
    [Burkholz et al., 2021](https://pubmed.ncbi.nlm.nih.gov/34133929/)
- **`NSequonPred`**
  - given the ESM-1b representation of an N-sequon (+/- 20 AA), this
    model can predict whether the sequon will be glycosylated

## How to use

`Glycowork` currently contains four main modules:

- **`glycan_data`**
  - stores several glycan datasets and contains helper functions
- **`ml`**
  - here are all the functions for training and using machine learning
    models, including train-test-split, getting glycan representations,
    etc.
- **`motif`**
  - contains functions for processing glycan sequences, identifying
    motifs and features, and analyzing them
- **`network`**
  - contains functions for constructing and analyzing glycan networks
    (e.g., biosynthetic networks)

Below are some examples of what you can do with `glycowork`; be sure to
check out the other `examples` in the full documentation for everything
that’s there. A non-exhaustive list includes:

- using trained AI models for prediction
- training your own AI models
- motif enrichment analyses
- annotating motifs in glycans
- finding out whether & where glycans are describing the same sequence
- m/z to composition to structure to motif mappings
- mass calculation
- visualizing motif distribution / glycan similarities / sequence
  properties
- constructing and analyzing biosynthetic networks

``` python
#get motifs, graph features, and sequence features of a set of glycan sequences to train models or analyze glycan properties
glycans = ['Man(a1-3)[Man(a1-6)][Xyl(b1-2)]Man(b1-4)GlcNAc(b1-4)[Fuc(a1-3)]GlcNAc',
           'Man(a1-2)Man(a1-2)Man(a1-3)[Man(a1-3)Man(a1-6)]Man(b1-4)GlcNAc(b1-4)GlcNAc',
           'GalNAc(a1-4)GlcNAcA(a1-4)[GlcN(b1-7)]Kdo(a2-5)[Kdo(a2-4)]Kdo(a2-6)GlcN4P(b1-6)GlcN1P']
from glycowork.motif.annotate import annotate_dataset
out = annotate_dataset(glycans, feature_set = ['known', 'graph', 'exhaustive']).head()
```

<table border="1" class="dataframe">
  <thead>
    <tr style="text-align: right;">
      <th></th>
      <th>LewisX</th>
      <th>LewisY</th>
      <th>SialylLewisX</th>
      <th>SulfoSialylLewisX</th>
      <th>LewisA</th>
      <th>LewisB</th>
      <th>SialylLewisA</th>
      <th>SulfoLewisA</th>
      <th>H_type2</th>
      <th>H_type1</th>
      <th>A_antigen</th>
      <th>B_antigen</th>
      <th>Galili_antigen</th>
      <th>GloboH</th>
      <th>Gb5</th>
      <th>Gb4</th>
      <th>Gb3</th>
      <th>3SGb3</th>
      <th>8DSGb3</th>
      <th>3SGb4</th>
      <th>8DSGb4</th>
      <th>6DSGb4</th>
      <th>3SGb5</th>
      <th>8DSGb5</th>
      <th>6DSGb5</th>
      <th>6DSGb5_2</th>
      <th>6SGb3</th>
      <th>8DSGb3_2</th>
      <th>6SGb4</th>
      <th>8DSGb4_2</th>
      <th>6SGb5</th>
      <th>8DSGb5_2</th>
      <th>66DSGb5</th>
      <th>Forssman_antigen</th>
      <th>iGb3</th>
      <th>I_antigen</th>
      <th>i_antigen</th>
      <th>PI_antigen</th>
      <th>Chitobiose</th>
      <th>Trimannosylcore</th>
      <th>Internal_LacNAc_type1</th>
      <th>Terminal_LacNAc_type1</th>
      <th>Internal_LacNAc_type2</th>
      <th>Terminal_LacNAc_type2</th>
      <th>Internal_LacdiNAc_type1</th>
      <th>Terminal_LacdiNAc_type1</th>
      <th>Internal_LacdiNAc_type2</th>
      <th>Terminal_LacdiNAc_type2</th>
      <th>bisectingGlcNAc</th>
      <th>VIM</th>
      <th>PolyLacNAc</th>
      <th>Ganglio_Series</th>
      <th>Lacto_Series(LewisC)</th>
      <th>NeoLacto_Series</th>
      <th>betaGlucan</th>
      <th>KeratanSulfate</th>
      <th>Hyluronan</th>
      <th>Mollu_series</th>
      <th>Arthro_series</th>
      <th>Cellulose_like</th>
      <th>Chondroitin_4S</th>
      <th>GPI_anchor</th>
      <th>Isoglobo_series</th>
      <th>LewisD</th>
      <th>Globo_series</th>
      <th>Sda</th>
      <th>SDA</th>
      <th>Muco_series</th>
      <th>Heparin</th>
      <th>Peptidoglycan</th>
      <th>Dermatansulfate</th>
      <th>CAD</th>
      <th>Lactosylceramide</th>
      <th>Lactotriaosylceramide</th>
      <th>LexLex</th>
      <th>GM3</th>
      <th>H_type3</th>
      <th>GM2</th>
      <th>GM1</th>
      <th>cisGM1</th>
      <th>VIM2</th>
      <th>GD3</th>
      <th>GD1a</th>
      <th>GD2</th>
      <th>GD1b</th>
      <th>SDLex</th>
      <th>Nglycolyl_GM2</th>
      <th>Fuc_LN3</th>
      <th>GT1b</th>
      <th>GD1</th>
      <th>GD1a_2</th>
      <th>LcGg4</th>
      <th>GT3</th>
      <th>Disialyl_T_antigen</th>
      <th>GT1a</th>
      <th>GT2</th>
      <th>GT1c</th>
      <th>2Fuc_GM1</th>
      <th>GQ1c</th>
      <th>O_linked_mannose</th>
      <th>GT1aa</th>
      <th>GQ1b</th>
      <th>HNK1</th>
      <th>GQ1ba</th>
      <th>O_mannose_Lex</th>
      <th>2Fuc_GD1b</th>
      <th>Sialopentaosylceramide</th>
      <th>Sulfogangliotetraosylceramide</th>
      <th>B-GM1</th>
      <th>GQ1aa</th>
      <th>bisSulfo-Lewis x</th>
      <th>para-Forssman</th>
      <th>core_fucose</th>
      <th>core_fucose(a1-3)</th>
      <th>GP1c</th>
      <th>B-GD1b</th>
      <th>GP1ca</th>
      <th>Isoglobotetraosylceramide</th>
      <th>polySia</th>
      <th>high_mannose</th>
      <th>Gala_series</th>
      <th>LPS_core</th>
      <th>Nglycan_complex</th>
      <th>Nglycan_complex2</th>
      <th>Oglycan_core2</th>
      <th>Oglycan_core3</th>
      <th>Oglycan_core4</th>
      <th>Oglycan_core5</th>
      <th>Oglycan_core6</th>
      <th>Oglycan_core7</th>
      <th>Xylogalacturonan</th>
      <th>Sialosylparagloboside</th>
      <th>LDNF</th>
      <th>OFuc</th>
      <th>Arabinogalactan_type2</th>
      <th>EGF_repeat</th>
      <th>Nglycan_hybrid</th>
      <th>Arabinan</th>
      <th>Xyloglucan</th>
      <th>Acharan_Sulfate</th>
      <th>M3FX</th>
      <th>M3X</th>
      <th>1-6betaGalactan</th>
      <th>Arabinogalactan_type1</th>
      <th>Galactomannan</th>
      <th>Tetraantennary_Nglycan</th>
      <th>Mucin_elongated_core2</th>
      <th>Fucoidan</th>
      <th>Alginate</th>
      <th>FG</th>
      <th>XX</th>
      <th>Difucosylated_core</th>
      <th>GalFuc_core</th>
      <th>diameter</th>
      <th>branching</th>
      <th>nbrLeaves</th>
      <th>avgDeg</th>
      <th>varDeg</th>
      <th>maxDeg</th>
      <th>nbrDeg4</th>
      <th>max_deg_leaves</th>
      <th>mean_deg_leaves</th>
      <th>deg_assort</th>
      <th>betweeness</th>
      <th>betwVar</th>
      <th>betwMax</th>
      <th>eigenMax</th>
      <th>eigenMin</th>
      <th>eigenAvg</th>
      <th>eigenVar</th>
      <th>closeMax</th>
      <th>closeMin</th>
      <th>closeAvg</th>
      <th>closeVar</th>
      <th>flowMax</th>
      <th>flowAvg</th>
      <th>flowVar</th>
      <th>flow_edgeMax</th>
      <th>flow_edgeMin</th>
      <th>flow_edgeAvg</th>
      <th>flow_edgeVar</th>
      <th>loadMax</th>
      <th>loadAvg</th>
      <th>loadVar</th>
      <th>harmMax</th>
      <th>harmMin</th>
      <th>harmAvg</th>
      <th>harmVar</th>
      <th>secorderMax</th>
      <th>secorderMin</th>
      <th>secorderAvg</th>
      <th>secorderVar</th>
      <th>size_corona</th>
      <th>size_core</th>
      <th>nbr_node_types</th>
      <th>egap</th>
      <th>entropyStation</th>
      <th>N</th>
      <th>dens</th>
      <th>0dHex</th>
      <th>1,4-Anhydro-Gal-ol</th>
      <th>1,5-Anhydro-D-AltNAc-ol</th>
      <th>1,5-Anhydro-D-FucN-ol</th>
      <th>1,5-Anhydro-D-Rha4NAc-ol</th>
      <th>1,5-Anhydro-Gal-ol</th>
      <th>1,5-Anhydro-GalNAc-ol</th>
      <th>1,5-Anhydro-Glc-ol</th>
      <th>1,5-Anhydro-Glc-onic</th>
      <th>1,5-Anhydro-GlcN2S-ol</th>
      <th>1,5-Anhydro-GlcN2S6S-ol</th>
      <th>1,5-Anhydro-GlcNAc-ol</th>
      <th>1,5-Anhydro-GlcNAc-onic</th>
      <th>1,5-Anhydro-Man-ol</th>
      <th>1,5-Anhydro-ManNAc-ol</th>
      <th>1,5-Anhydro-Xyl-ol</th>
      <th>1,5-Anhydro-Xyl2F-ol</th>
      <th>1-1</th>
      <th>1-2</th>
      <th>1-3</th>
      <th>1-4</th>
      <th>1-5</th>
      <th>1-6</th>
      <th>1-?</th>
      <th>1dAlt-ol</th>
      <th>1dEry-ol</th>
      <th>2,3-Anhydro-All</th>
      <th>2,3-Anhydro-Man</th>
      <th>2,3-Anhydro-Rib</th>
      <th>2,5-Anhydro-D-Alt-ol</th>
      <th>2,5-Anhydro-D-Alt3S-ol</th>
      <th>2,5-Anhydro-D-Tal</th>
      <th>2,5-Anhydro-Glc</th>
      <th>2,5-Anhydro-L-Man-ol</th>
      <th>2,5-Anhydro-Man</th>
      <th>2,5-Anhydro-Man-ol</th>
      <th>2,5-Anhydro-Man1S-ol</th>
      <th>2,5-Anhydro-Man3S-ol</th>
      <th>2,5-Anhydro-Man6S</th>
      <th>2,5-Anhydro-Tal-ol</th>
      <th>2,5-Anhydro-Tal6P</th>
      <th>2,6-Anhydro-Glc5NAc-ol</th>
      <th>2,6-Anhydro-L-Gul-ol</th>
      <th>2,6-Anhydro-L-Gul-onic</th>
      <th>2,6-Anhydro-Man-ol</th>
      <th>2,6-Anhydro-Tal5NAc-ol</th>
      <th>2,7-Anhydro-Kdo</th>
      <th>2,7-Anhydro-Kdof</th>
      <th>2-3</th>
      <th>2-4</th>
      <th>2-5</th>
      <th>2-6</th>
      <th>3,6-Anhydro-Fruf</th>
      <th>3,6-Anhydro-Gal</th>
      <th>3,6-Anhydro-Gal2S</th>
      <th>3,6-Anhydro-Glc</th>
      <th>3,6-Anhydro-L-Gal</th>
      <th>3,6-Anhydro-L-Gal2Me</th>
      <th>3-1</th>
      <th>3-5</th>
      <th>3-Anhydro-Gal</th>
      <th>3-Anhydro-Gal2S</th>
      <th>3dFuc</th>
      <th>3dGal</th>
      <th>3dLyxHep-ulosaric</th>
      <th>4,7-Anhydro-Kdo</th>
      <th>4,7-Anhydro-KdoOPEtN</th>
      <th>4,8-Anhydro-Kdo</th>
      <th>4-1</th>
      <th>4-5</th>
      <th>4d8dNeu5Ac</th>
      <th>4dAraHex</th>
      <th>4dEry-ol</th>
      <th>4dFuc</th>
      <th>4dGal</th>
      <th>4dNeu5Ac</th>
      <th>4dThrHexNAcA4en</th>
      <th>4eLeg5Ac7Ac</th>
      <th>5-1</th>
      <th>5-2</th>
      <th>5-3</th>
      <th>5-4</th>
      <th>5-5</th>
      <th>5-6</th>
      <th>5dAraf</th>
      <th>5dAraf3Me</th>
      <th>5dLyxf3CFo</th>
      <th>5dLyxf3CMe</th>
      <th>5dPenf3CFo</th>
      <th>6-1</th>
      <th>6-3</th>
      <th>6-4</th>
      <th>6dAll</th>
      <th>6dAll3Me</th>
      <th>6dAlt</th>
      <th>6dAltNAc</th>
      <th>6dAltNAc1PP4N</th>
      <th>6dAltNAc1PP4NAc</th>
      <th>6dAltNAc3PCho</th>
      <th>6dAltOAc</th>
      <th>6dAltf</th>
      <th>6dAltfOAc</th>
      <th>6dFruf</th>
      <th>6dGal</th>
      <th>6dGalNAc</th>
      <th>6dGul</th>
      <th>6dHex</th>
      <th>6dHexN</th>
      <th>6dHexNAc4NAc</th>
      <th>6dManHep</th>
      <th>6dTal</th>
      <th>6dTal1PP</th>
      <th>6dTal2Ac</th>
      <th>6dTal2Ac3Ac</th>
      <th>6dTal2Ac3Ac4Ac</th>
      <th>6dTal2Ac3Me</th>
      <th>6dTal2Ac3Me4Ac</th>
      <th>6dTal2Ac4Ac</th>
      <th>6dTal2Me</th>
      <th>6dTal2Me4Ac</th>
      <th>6dTal3Me</th>
      <th>6dTal4Ac</th>
      <th>6dTalNAc</th>
      <th>6dTalNAc1PP</th>
      <th>6dTalNAc4Ac</th>
      <th>6dTalNAcOAc</th>
      <th>6dTalOAc</th>
      <th>6dTalOAcOAc</th>
      <th>6dTalOAcOMe</th>
      <th>6dTalOMe</th>
      <th>6dTalOMe-ol</th>
      <th>6dTalf</th>
      <th>7dNeu5Ac</th>
      <th>8dNeu5Ac</th>
      <th>8eAci5Ac7Ac</th>
      <th>8eLeg</th>
      <th>8eLeg5Ac7Ac</th>
      <th>8eLeg5Ac7Ac8Ac</th>
      <th>8eLeg5Ac7AcGro</th>
      <th>8eLeg5But7Ac</th>
      <th>8eLegNAcNBut</th>
      <th>9dNeu5Ac</th>
      <th>?1-3</th>
      <th>?1-4</th>
      <th>?1-?</th>
      <th>?2-?</th>
      <th>Abe</th>
      <th>Abe1PP</th>
      <th>Abe2Ac</th>
      <th>AbeOAc</th>
      <th>AcefA</th>
      <th>Aci5Ac7Ac</th>
      <th>AcoNAc</th>
      <th>All</th>
      <th>All-ol</th>
      <th>All1S2S3S4S</th>
      <th>All2Ac3Ac</th>
      <th>All2S3S4S</th>
      <th>All3Ac</th>
      <th>All6Ac</th>
      <th>AllN</th>
      <th>AllN1P</th>
      <th>AllNAc</th>
      <th>AllNAc6Me</th>
      <th>AllOMe</th>
      <th>Alt</th>
      <th>AltA</th>
      <th>AltA2N</th>
      <th>AltA2S</th>
      <th>AltAN</th>
      <th>AltNAc</th>
      <th>AltNAcA</th>
      <th>AltNAcA1Prop</th>
      <th>Altf</th>
      <th>AltfOAc</th>
      <th>Api</th>
      <th>ApiOAc</th>
      <th>ApiOMe-ol</th>
      <th>Apif</th>
      <th>Ara</th>
      <th>Ara-ol</th>
      <th>Ara1Me</th>
      <th>Ara1N4P</th>
      <th>Ara1P4N</th>
      <th>Ara1PP</th>
      <th>Ara1PP2NAc</th>
      <th>Ara1PP4N</th>
      <th>Ara1PP4NFo</th>
      <th>Ara2Ac</th>
      <th>Ara2Ac3Ac4Ac</th>
      <th>Ara2Ac4Ac</th>
      <th>Ara2Ac5P-ol</th>
      <th>Ara2Me</th>
      <th>Ara2P</th>
      <th>Ara3Ac</th>
      <th>Ara3Ac4Ac</th>
      <th>Ara3Me</th>
      <th>Ara3N</th>
      <th>Ara4Ac</th>
      <th>Ara4N</th>
      <th>Ara4S</th>
      <th>AraN</th>
      <th>AraNMeOMe</th>
      <th>AraOAc</th>
      <th>AraOAcOP-ol</th>
      <th>AraOMe</th>
      <th>AraOPN</th>
      <th>Araf</th>
      <th>Araf1Coum</th>
      <th>Araf1Fer</th>
      <th>Araf1Gro</th>
      <th>Araf1P</th>
      <th>Araf1PP</th>
      <th>Araf2Ac3Ac5Ac</th>
      <th>Araf2Me</th>
      <th>Araf3Me</th>
      <th>Araf3S</th>
      <th>ArafGro</th>
      <th>ArafOMe</th>
      <th>Asc</th>
      <th>Bac</th>
      <th>Bac1N2Ac4Ac</th>
      <th>Bac1PP2Ac</th>
      <th>Bac1PP2Ac4Ac</th>
      <th>Bac2Ac</th>
      <th>Bac2Ac4Ac</th>
      <th>Col</th>
      <th>Col1PP</th>
      <th>D-2,7-Anhydro-3dManHep-ulosonic</th>
      <th>D-2dAraHex</th>
      <th>D-2dAraHexA</th>
      <th>D-3dAraHep-ulosonic</th>
      <th>D-3dLyxHep-ulosaric</th>
      <th>D-3dLyxHep2Me-ulosaric</th>
      <th>D-3dManHep-ulosonic</th>
      <th>D-3dThrHex-ulosonic</th>
      <th>D-3dThrPen</th>
      <th>D-3dXylHexOMe</th>
      <th>D-4dAraHex</th>
      <th>D-4dEryHexOAcN4en</th>
      <th>D-4dLyxHep</th>
      <th>D-4dLyxHep1Me</th>
      <th>D-4dLyxHex</th>
      <th>D-4dLyxHexOMe</th>
      <th>D-4dThrHexA4en</th>
      <th>D-4dThrHexAN4en</th>
      <th>D-4dThrHexOAcN4en</th>
      <th>D-4dXylHex</th>
      <th>D-6dAllOMe</th>
      <th>D-6dAlt</th>
      <th>D-6dAltHep</th>
      <th>D-6dAltHep3Me</th>
      <th>D-6dAltHepf</th>
      <th>D-6dAraHex</th>
      <th>D-6dAraHexN</th>
      <th>D-6dAraHexNAc</th>
      <th>D-6dAraHexOMe</th>
      <th>D-6dIdoHep</th>
      <th>D-6dLyxHexOMe</th>
      <th>D-6dManHep</th>
      <th>D-6dManHep1P</th>
      <th>D-6dManHep2Ac</th>
      <th>D-6dManHep3Ac</th>
      <th>D-6dManHepOAc</th>
      <th>D-6dManHepOP</th>
      <th>D-6dTal</th>
      <th>D-6dTal-ol</th>
      <th>D-6dTal2Ac</th>
      <th>D-6dTal2Ac3Ac</th>
      <th>D-6dTal2Ac4Ac</th>
      <th>D-6dTal3Me</th>
      <th>D-6dTal3Me-ol</th>
      <th>D-6dTal4Ac</th>
      <th>D-6dTalHep</th>
      <th>D-6dTalOAc</th>
      <th>D-6dTalOAcOMe</th>
      <th>D-6dTalOMe</th>
      <th>D-6dXylHex</th>
      <th>D-6dXylHexN4Ulo</th>
      <th>D-6dXylHexNAc4Ulo</th>
      <th>D-6dXylHexOMe</th>
      <th>D-7dLyxOct-ulosonic</th>
      <th>D-9dThrAltNon-onic</th>
      <th>D-All6Ac</th>
      <th>D-AllN</th>
      <th>D-Alt</th>
      <th>D-Alt1Me</th>
      <th>D-Alt2S3S4S</th>
      <th>D-Alt3S4S</th>
      <th>D-Apif</th>
      <th>D-Apif1PP</th>
      <th>D-Apif2Ac</th>
      <th>D-ApifOAc</th>
      <th>D-ApifOMe</th>
      <th>D-Ara</th>
      <th>D-Ara-aric</th>
      <th>D-Ara-ol</th>
      <th>D-Ara-onic</th>
      <th>D-Ara1P-ol</th>
      <th>D-Ara2S4S</th>
      <th>D-Ara4S</th>
      <th>D-Araf</th>
      <th>D-Araf1Me</th>
      <th>D-Araf2Ac3Ac5Ac</th>
      <th>D-ArafN</th>
      <th>D-Fuc</th>
      <th>D-Fuc-ol</th>
      <th>D-Fuc1CoumOMe</th>
      <th>D-Fuc1FerOMe</th>
      <th>D-Fuc1Gro</th>
      <th>D-Fuc1Gro3NBut</th>
      <th>D-Fuc2Ac</th>
      <th>D-Fuc2Ac3Me</th>
      <th>D-Fuc2Me</th>
      <th>D-Fuc2Me3Me</th>
      <th>D-Fuc2Me3Me4N</th>
      <th>D-Fuc2Me4NAc</th>
      <th>D-Fuc2S</th>
      <th>D-Fuc3Ac</th>
      <th>D-Fuc3Ac4Ac</th>
      <th>D-Fuc3Me</th>
      <th>D-Fuc3N</th>
      <th>D-Fuc3NAlaAc</th>
      <th>D-Fuc3NBut</th>
      <th>D-Fuc3NBut4Ac</th>
      <th>D-Fuc3NFo</th>
      <th>D-Fuc3NLac</th>
      <th>D-Fuc3S</th>
      <th>D-Fuc4Ac</th>
      <th>D-Fuc4CN</th>
      <th>D-Fuc4Me</th>
      <th>D-Fuc4N</th>
      <th>D-Fuc4NBut</th>
      <th>D-Fuc4NMe</th>
      <th>D-Fuc4S</th>
      <th>D-FucN</th>
      <th>D-FucNAc</th>
      <th>D-FucNAc-ol</th>
      <th>D-FucNAc1Prop4N</th>
      <th>D-FucNAc4Ac</th>
      <th>D-FucNAc4N</th>
      <th>D-FucNAc4NAc</th>
      <th>D-FucNAc4NMe</th>
      <th>D-FucNAcN</th>
      <th>D-FucNAcNMe</th>
      <th>D-FucNAcNMeN</th>
      <th>D-FucNAcOAc</th>
      <th>D-FucNAcOMe</th>
      <th>D-FucNAcOP</th>
      <th>D-FucNAcOPEtN</th>
      <th>D-FucNAlaAc</th>
      <th>D-FucNAsp</th>
      <th>D-FucNBut</th>
      <th>D-FucNFo</th>
      <th>D-FucNMeN</th>
      <th>D-FucNThrAc</th>
      <th>D-FucOAc</th>
      <th>D-FucOAcNGroA</th>
      <th>D-FucOAcOBut</th>
      <th>D-FucOAcOMe</th>
      <th>D-FucOBut</th>
      <th>D-FucOEtN</th>
      <th>D-FucOMe</th>
      <th>D-FucOMe1Coum</th>
      <th>D-FucOMe1Fer</th>
      <th>D-FucOMeOSin</th>
      <th>D-FucOS</th>
      <th>D-Fucf</th>
      <th>D-Fucf2Ac</th>
      <th>D-FucfNAc</th>
      <th>D-FucfOAc</th>
      <th>D-Ido</th>
      <th>D-IdoA</th>
      <th>D-IdoA2S</th>
      <th>D-IdoNAc</th>
      <th>D-IdoNAc1N</th>
      <th>D-Lyx</th>
      <th>D-Rha</th>
      <th>D-Rha-ol</th>
      <th>D-Rha1F4NFo</th>
      <th>D-Rha1PP</th>
      <th>D-Rha1PP4N</th>
      <th>D-Rha1PP4NAc</th>
      <th>D-Rha2Me</th>
      <th>D-Rha2Me3Me4NFo</th>
      <th>D-Rha2Me4Me</th>
      <th>D-Rha2Me4N</th>
      <th>D-Rha2Me4NBut</th>
      <th>D-Rha2Me4NFo</th>
      <th>D-Rha2S</th>
      <th>D-Rha3Ac4Ac</th>
      <th>D-Rha3CMe</th>
      <th>D-Rha3Me</th>
      <th>D-Rha3N</th>
      <th>D-Rha3P</th>
      <th>D-Rha4N</th>
      <th>D-Rha4NAc</th>
      <th>D-Rha4NBut</th>
      <th>D-Rha4NFo</th>
      <th>D-Rha4NLac</th>
      <th>D-RhaCMe</th>
      <th>D-RhaGro</th>
      <th>D-RhaN</th>
      <th>D-RhaNAc</th>
      <th>D-RhaNAc2Me3Me</th>
      <th>D-RhaNAcOAc</th>
      <th>D-RhaNFo</th>
      <th>D-RhaOMe</th>
      <th>D-RhaOP</th>
      <th>D-RhaOS</th>
      <th>D-Sor</th>
      <th>D-Sorf</th>
      <th>D-Sorf1Cl4Cl6Cl</th>
      <th>D-Thre-ol</th>
      <th>DDAltHep</th>
      <th>DDAltHep3Me</th>
      <th>DDAltHepOMe</th>
      <th>DDGalHep</th>
      <th>DDGalHepOMe</th>
      <th>DDGlcHep</th>
      <th>DDManHep</th>
      <th>DDManHep2PEtN7PEtN</th>
      <th>DDManHep3P6P</th>
      <th>DDManHep7PCho</th>
      <th>DDManHepOAc</th>
      <th>DDManHepOBut</th>
      <th>DDManHepOEtN</th>
      <th>DDManHepOMe</th>
      <th>DDManHepOP</th>
      <th>DDManHepOPEtN</th>
      <th>DDManHepOPGroA</th>
      <th>DDManHepPGroA</th>
      <th>DL-3,9dGalNon5NAc7NAc-ulosonic</th>
      <th>DL-3,9dGlcNon5NAm7Ac-ulosonic</th>
      <th>DL-3,9dGlcNon5NAm7Am-ulosonic</th>
      <th>DLGlcHep3Me6Me</th>
      <th>DLGlcHep6Me</th>
      <th>DLGlcHepOMe</th>
      <th>DLHepGlcOMe</th>
      <th>Dha</th>
      <th>Dig</th>
      <th>Dig3Ac</th>
      <th>Dig3Ac4Ac</th>
      <th>Dig3CMe</th>
      <th>Dig3Fo</th>
      <th>Dig3Fo4Fo</th>
      <th>Dig3Me</th>
      <th>Dig3Me4Me</th>
      <th>Dig4Ac</th>
      <th>Dig4Me</th>
      <th>DigOAc</th>
      <th>DigOMe</th>
      <th>Erwiniose</th>
      <th>Ery-ol</th>
      <th>Ery-onic</th>
      <th>Ery4Ac-ol</th>
      <th>EryOMe-onic</th>
      <th>Fru</th>
      <th>Fru3MeOPN</th>
      <th>Fruf</th>
      <th>Fruf1Ac</th>
      <th>Fruf1Ac4Ac</th>
      <th>Fruf1Cl4Br6Cl</th>
      <th>Fruf1Cl4Cl6Cl</th>
      <th>Fruf1Cl4F6Cl</th>
      <th>Fruf1Cl4I6Cl</th>
      <th>Fruf1Cl4Me6Cl</th>
      <th>Fruf1Cl6Cl</th>
      <th>Fruf1CoumOAcOBz</th>
      <th>Fruf1CoumOBz</th>
      <th>Fruf1Fer</th>
      <th>Fruf1FerOAc</th>
      <th>Fruf1FerOBz</th>
      <th>Fruf1S3S4S6S</th>
      <th>Fruf3Ac</th>
      <th>Fruf4Ac</th>
      <th>Fruf4Ac6Ac</th>
      <th>Fruf4F</th>
      <th>Fruf6Ac</th>
      <th>Fruf6Br</th>
      <th>Fruf6F</th>
      <th>Fruf6I</th>
      <th>Fruf6Lau</th>
      <th>Fruf6Me</th>
      <th>Fruf6N</th>
      <th>Fruf6NAc</th>
      <th>Fruf6P</th>
      <th>FrufOAc</th>
      <th>FrufOAc1Fer</th>
      <th>FrufOAcOBz1Coum</th>
      <th>FrufOBz1Coum</th>
      <th>FrufOBz1Fer</th>
      <th>FrufOBzOCin</th>
      <th>FrufOLau</th>
      <th>Fuc</th>
      <th>Fuc-ol</th>
      <th>Fuc1N</th>
      <th>Fuc1N4NBz7Et-ol</th>
      <th>Fuc1P</th>
      <th>Fuc1PP</th>
      <th>Fuc1PamOMe</th>
      <th>Fuc1VacOMe</th>
      <th>Fuc2Ac</th>
      <th>Fuc2Ac3Ac4Ac</th>
      <th>Fuc2Me</th>
      <th>Fuc2Me3Me</th>
      <th>Fuc2Me3Me4Ac</th>
      <th>Fuc2Me3Me4Me</th>
      <th>Fuc2Me3S</th>
      <th>Fuc2Me4Ac</th>
      <th>Fuc2Me4Me</th>
      <th>Fuc2Me4NAc</th>
      <th>Fuc2N</th>
      <th>Fuc2NAm</th>
      <th>Fuc2S</th>
      <th>Fuc2S3S4S</th>
      <th>Fuc2S4S</th>
      <th>Fuc3Ac</th>
      <th>Fuc3Ac4Ac</th>
      <th>Fuc3Me</th>
      <th>Fuc3Me4Me</th>
      <th>Fuc3N</th>
      <th>Fuc3NBut4Ac</th>
      <th>Fuc3NGly</th>
      <th>Fuc3NMe</th>
      <th>Fuc3S</th>
      <th>Fuc3S4S</th>
      <th>Fuc4Ac</th>
      <th>Fuc4Me</th>
      <th>Fuc4N</th>
      <th>Fuc4NBut</th>
      <th>Fuc4S</th>
      <th>FucN</th>
      <th>FucNAc</th>
      <th>FucNAc-ol</th>
      <th>FucNAc1PP</th>
      <th>FucNAc3Ac</th>
      <th>FucNAc4NMe</th>
      <th>FucNAcA</th>
      <th>FucNAcN</th>
      <th>FucNAcNMe</th>
      <th>FucNAcOAc</th>
      <th>FucNAcPGro</th>
      <th>FucNAla</th>
      <th>FucNAm</th>
      <th>FucNAm1Me</th>
      <th>FucNAm3Ac</th>
      <th>FucNBut</th>
      <th>FucNFo</th>
      <th>FucNProp</th>
      <th>FucNThrAc</th>
      <th>FucOAc</th>
      <th>FucOAcNAm</th>
      <th>FucOAcOMe</th>
      <th>FucOAcOSOMe</th>
      <th>FucOMe</th>
      <th>FucOMe1Pam</th>
      <th>FucOMe1Vac</th>
      <th>FucOPOMe</th>
      <th>FucOS</th>
      <th>FucOSOMe</th>
      <th>Fucf</th>
      <th>FucfNAc</th>
      <th>Fus5Ac</th>
      <th>Fus5Am</th>
      <th>Gal</th>
      <th>Gal-ol</th>
      <th>Gal-onic</th>
      <th>Gal1Cer</th>
      <th>Gal1Cer3S</th>
      <th>Gal1Et</th>
      <th>Gal1EtN</th>
      <th>Gal1Gro</th>
      <th>Gal1Me</th>
      <th>Gal1Me3P</th>
      <th>Gal1P</th>
      <th>Gal1PGro</th>
      <th>Gal1PGro2Ac3Ac</th>
      <th>Gal1PP</th>
      <th>Gal1S</th>
      <th>Gal2Ac</th>
      <th>Gal2Ac3Ac</th>
      <th>Gal2Ac3Ac4Ac</th>
      <th>Gal2Ac3Ac4Ac6Ac</th>
      <th>Gal2Ac3Ac4Pyr</th>
      <th>Gal2Ac3Ac6Ac</th>
      <th>Gal2Ac4Ac</th>
      <th>Gal2Ac4Ac6Ac</th>
      <th>Gal2Ac4Pyr</th>
      <th>Gal2Et3S4S6Et</th>
      <th>Gal2Et4S6Et</th>
      <th>Gal2F</th>
      <th>Gal2F3Me</th>
      <th>Gal2Me</th>
      <th>Gal2Me3Me</th>
      <th>Gal2Me3Me4Me</th>
      <th>Gal2Me6Me</th>
      <th>Gal2N</th>
      <th>Gal2NAla</th>
      <th>Gal2PCho</th>
      <th>Gal2PGro</th>
      <th>Gal2PGro6MeOPN</th>
      <th>Gal2Pyr</th>
      <th>Gal2S</th>
      <th>Gal2S3S</th>
      <th>Gal2S3S4S6S</th>
      <th>Gal2S6S</th>
      <th>Gal3Ac</th>
      <th>Gal3Ac4Ac</th>
      <th>Gal3Ac4Ac6Ac</th>
      <th>Gal3Ac6Ac</th>
      <th>Gal3CN</th>
      <th>Gal3Cl6Cl</th>
      <th>Gal3F</th>
      <th>Gal3Lac</th>
      <th>Gal3Me</th>
      <th>Gal3Me4Cl6Cl</th>
      <th>Gal3Me4S</th>
      <th>Gal3Me6S</th>
      <th>Gal3N</th>
      <th>Gal3NAc</th>
      <th>Gal3P</th>
      <th>Gal3P4P</th>
      <th>Gal3PCho</th>
      <th>Gal3PCho6PEtN</th>
      <th>Gal3PGro</th>
      <th>Gal3Pyr</th>
      <th>Gal3Pyr4Pyr</th>
      <th>Gal3S</th>
      <th>Gal3S4S</th>
      <th>Gal3S6Et</th>
      <th>Gal3S6S</th>
      <th>Gal4Ac</th>
      <th>Gal4Ac6Ac</th>
      <th>Gal4Cl</th>
      <th>Gal4F</th>
      <th>Gal4Me</th>
      <th>Gal4Me6Me</th>
      <th>Gal4N</th>
      <th>Gal4NAc</th>
      <th>Gal4NAc5NAc-onic</th>
      <th>Gal4P</th>
      <th>Gal4P6P</th>
      <th>Gal4PGro</th>
      <th>Gal4Pyr</th>
      <th>Gal4Pyr6Pyr</th>
      <th>Gal4S</th>
      <th>Gal4S6S</th>
      <th>Gal5NAc-ol</th>
      <th>Gal6Ac</th>
      <th>Gal6Aep</th>
      <th>Gal6F</th>
      <th>Gal6Lac-ol</th>
      <th>Gal6Me</th>
      <th>Gal6N</th>
      <th>Gal6NAc</th>
      <th>Gal6P</th>
      <th>Gal6PCho</th>
      <th>Gal6PChoOAc</th>
      <th>Gal6PEtN</th>
      <th>Gal6PGro</th>
      <th>Gal6Pyr</th>
      <th>Gal6S</th>
      <th>Gal6S-ol</th>
      <th>Gal6ulo</th>
      <th>GalA</th>
      <th>GalA-ol</th>
      <th>GalA1Me</th>
      <th>GalA1P</th>
      <th>GalA1P6N</th>
      <th>GalA1PP</th>
      <th>GalA1PP2NAc</th>
      <th>GalA1Prop</th>
      <th>GalA2Ac</th>
      <th>GalA2Ac3Ac</th>
      <th>GalA2Ac4Fo</th>
      <th>GalA2N</th>
      <th>GalA2NAc</th>
      <th>GalA2NAc3Ac</th>
      <th>GalA2NAc3Ac4Me</th>
      <th>GalA2NAc3Ac6N</th>
      <th>GalA2NAc3NAc6N</th>
      <th>GalA2NAc6Me</th>
      <th>GalA2NAc6N</th>
      <th>GalA2NFo</th>
      <th>GalA2S</th>
      <th>GalA2S3S</th>
      <th>GalA2S3S6Me</th>
      <th>GalA3Ac</th>
      <th>GalA3Ac4Ac6GroN</th>
      <th>GalA3Ac6Thr</th>
      <th>GalA3Me</th>
      <th>GalA3Me4Ac6Me</th>
      <th>GalA3P</th>
      <th>GalA4Ac</th>
      <th>GalA4Ac6Ser</th>
      <th>GalA4Me</th>
      <th>GalA4PEtN6Lys</th>
      <th>GalA6Ala</th>
      <th>GalA6CetLys</th>
      <th>GalA6Lys</th>
      <th>GalA6Me</th>
      <th>GalA6N</th>
      <th>GalA6Ser</th>
      <th>GalA6Thr</th>
      <th>GalA6ThrAc</th>
      <th>GalAAla</th>
      <th>GalAAlaLys</th>
      <th>GalAGroN</th>
      <th>GalALys</th>
      <th>GalAN</th>
      <th>GalANCys</th>
      <th>GalANCysAc</th>
      <th>GalANSerAc</th>
      <th>GalAOAc</th>
      <th>GalAOAcGroN</th>
      <th>GalAOAcNAm</th>
      <th>GalAOAcOLac</th>
      <th>GalAOAcOMe</th>
      <th>GalAOAcThr</th>
      <th>GalAOLac</th>
      <th>GalAOMe</th>
      <th>GalAOP</th>
      <th>GalAOPEtN</th>
      <th>GalAOPyr</th>
      <th>GalAP3</th>
      <th>GalASer</th>
      <th>GalAThr</th>
      <th>GalGro</th>
      <th>GalGroN</th>
      <th>GalN</th>
      <th>GalN-ol</th>
      <th>GalN1P</th>
      <th>GalN1PP</th>
      <th>GalN2Ac</th>
      <th>GalN2Ala</th>
      <th>GalN2Suc</th>
      <th>GalN2Suc-ol</th>
      <th>GalN6Me</th>
      <th>GalN6PEtN</th>
      <th>GalNAc</th>
      <th>GalNAc-ol</th>
      <th>GalNAc1EtN</th>
      <th>GalNAc1Me</th>
      <th>GalNAc1N</th>
      <th>GalNAc1P</th>
      <th>GalNAc1P3Ac</th>
      <th>GalNAc1PGro</th>
      <th>GalNAc1PP</th>
      <th>GalNAc1PP4S</th>
      <th>GalNAc1PP4S6S</th>
      <th>GalNAc3Ac</th>
      <th>GalNAc3Ac4Ac6Ac</th>
      <th>GalNAc3Ac4PGro</th>
      <th>GalNAc3Me</th>
      <th>GalNAc3P</th>
      <th>GalNAc3PCho</th>
      <th>GalNAc3PGro</th>
      <th>GalNAc3PGro6Ac</th>
      <th>GalNAc3PGroAN</th>
      <th>GalNAc3S</th>
      <th>GalNAc4Ac</th>
      <th>GalNAc4Ac6Ac</th>
      <th>GalNAc4Me</th>
      <th>GalNAc4PEtN</th>
      <th>GalNAc4PGro</th>
      <th>GalNAc4Pyr</th>
      <th>GalNAc4S</th>
      <th>GalNAc4S-ol</th>
      <th>GalNAc4S6S</th>
      <th>GalNAc6Ac</th>
      <th>GalNAc6Aep</th>
      <th>GalNAc6Me</th>
      <th>GalNAc6P</th>
      <th>GalNAc6PCho</th>
      <th>GalNAc6PEtN</th>
      <th>GalNAc6PGro</th>
      <th>GalNAc6S</th>
      <th>GalNAc6S-ol</th>
      <th>GalNAcA</th>
      <th>GalNAcA3Ac</th>
      <th>GalNAcA3Ac6N</th>
      <th>GalNAcA3Me</th>
      <th>GalNAcA3Myr</th>
      <th>GalNAcA4Ac</th>
      <th>GalNAcA6Ala</th>
      <th>GalNAcA6N</th>
      <th>GalNAcAAla</th>
      <th>GalNAcAN</th>
      <th>GalNAcAOAc</th>
      <th>GalNAcAOAcN</th>
      <th>GalNAcASer</th>
      <th>GalNAcGro</th>
      <th>GalNAcN</th>
      <th>GalNAcOAc</th>
      <th>GalNAcOAcOP</th>
      <th>GalNAcOMe</th>
      <th>GalNAcOP</th>
      <th>GalNAcOPCho</th>
      <th>GalNAcOPEtN</th>
      <th>GalNAcOPGro</th>
      <th>GalNAcOS</th>
      <th>GalNAcPGro</th>
      <th>GalNAla</th>
      <th>GalNAmA</th>
      <th>GalNBz</th>
      <th>GalNCysGly</th>
      <th>GalNFoA</th>
      <th>GalNFoA3Ac6N</th>
      <th>GalNFoA6N</th>
      <th>GalNFoAN</th>
      <th>GalNOAc</th>
      <th>GalNPCho</th>
      <th>GalOAc</th>
      <th>GalOAcN</th>
      <th>GalOAcNAla</th>
      <th>GalOAcNFoA</th>
      <th>GalOAcNFoAN</th>
      <th>GalOAcOMe</th>
      <th>GalOAcOP</th>
      <th>GalOAcOPGro</th>
      <th>GalOAcOPyr</th>
      <th>GalOAcPGro</th>
      <th>GalOFoAN</th>
      <th>GalOLac</th>
      <th>GalOLac-ol</th>
      <th>GalOMe</th>
      <th>GalOMeF</th>
      <th>GalOMeNAla</th>
      <th>GalOP</th>
      <th>GalOPCho</th>
      <th>GalOPEtN</th>
      <th>GalOPGro</th>
      <th>GalOPyr</th>
      <th>GalOS</th>
      <th>GalPCho</th>
      <th>GalPGro</th>
      <th>GalcNAc6P</th>
      <th>Galf</th>
      <th>Galf1Bn</th>
      <th>Galf1Et</th>
      <th>Galf1Me</th>
      <th>Galf1Oc</th>
      <th>Galf1P</th>
      <th>Galf1PP</th>
      <th>Galf2Ac</th>
      <th>Galf2Ac3Ac5Ac6Ac</th>
      <th>Galf3Ac</th>
      <th>Galf3Ac5Ac</th>
      <th>Galf3Ac6Ac</th>
      <th>Galf3Lac</th>
      <th>Galf4Pyr</th>
      <th>Galf5Ac6Ac</th>
      <th>Galf5P</th>
      <th>Galf5Pyr</th>
      <th>Galf6Ac</th>
      <th>Galf6P</th>
      <th>Galf6PCho</th>
      <th>Galf6PGro</th>
      <th>GalfGro</th>
      <th>GalfNAc</th>
      <th>GalfOAc</th>
      <th>GalfOAcGro</th>
      <th>GalfOAcOLac</th>
      <th>GalfOAcOPGro</th>
      <th>GalfOAcPGro</th>
      <th>GalfOP</th>
      <th>GalfOPCho</th>
      <th>GalfOPGro</th>
      <th>GalfPCho</th>
      <th>GalfPGro</th>
      <th>Glc</th>
      <th>Glc-ol</th>
      <th>Glc-onic</th>
      <th>Glc1</th>
      <th>Glc1Beh6Ac</th>
      <th>Glc1Cer</th>
      <th>Glc1Cer6Aep</th>
      <th>Glc1Coum</th>
      <th>Glc1Coum6Ac</th>
      <th>Glc1Et</th>
      <th>Glc1EtN</th>
      <th>Glc1EtN2Ac</th>
      <th>Glc1F</th>
      <th>Glc1Fer</th>
      <th>Glc1Fer6Ac</th>
      <th>Glc1Gro</th>
      <th>Glc1Gro6PEtN</th>
      <th>Glc1GroA</th>
      <th>Glc1Hxo</th>
      <th>Glc1Lin</th>
      <th>Glc1Lin6Ac</th>
      <th>Glc1Me</th>
      <th>Glc1Me2S3Me6S</th>
      <th>Glc1Me2S3S6S</th>
      <th>Glc1N</th>
      <th>Glc1N-ol</th>
      <th>Glc1N-onic</th>
      <th>Glc1N4Me</th>
      <th>Glc1NAc</th>
      <th>Glc1NGc</th>
      <th>Glc1Oco</th>
      <th>Glc1Ole</th>
      <th>Glc1Ole3Ac4Ac</th>
      <th>Glc1Ole3Ac4Ac6Ac</th>
      <th>Glc1Ole3P4P6Ac</th>
      <th>Glc1Ole3Pp4Pp</th>
      <th>Glc1Ole6Ac</th>
      <th>Glc1P</th>
      <th>Glc1P2Lau</th>
      <th>Glc1P2Lau3Dco</th>
      <th>Glc1P2Lau3Lau</th>
      <th>Glc1P2Myr3Myr</th>
      <th>Glc1P6Ac</th>
      <th>Glc1PEtN</th>
      <th>Glc1PGro</th>
      <th>Glc1PP</th>
      <th>Glc1PP3N</th>
      <th>Glc1PP6S</th>
      <th>Glc1Pam</th>
      <th>Glc1Pam6Ac</th>
      <th>Glc1PamOPN</th>
      <th>Glc1S</th>
      <th>Glc1S2Ac3Ac6Ac</th>
      <th>Glc1Ste6Ac</th>
      <th>Glc2Ac</th>
      <th>Glc2Ac3Ac</th>
      <th>Glc2Ac3Ac4Ac</th>
      <th>Glc2Ac3Ac4Ac6Ac</th>
      <th>Glc2Ac3Ac4PGro</th>
      <th>Glc2Ac3Ac5Ac6Ac</th>
      <th>Glc2Ac3Ac6Ac</th>
      <th>Glc2Ac3S</th>
      <th>Glc2Ac4Ac6Ac</th>
      <th>Glc2Ac4PGro</th>
      <th>Glc2Ac6Ac</th>
      <th>Glc2Ac6S</th>
      <th>Glc2Br</th>
      <th>Glc2Br3Ac4Ac6Br</th>
      <th>Glc2Et3S4S6Et</th>
      <th>Glc2Et4S6Et</th>
      <th>Glc2F</th>
      <th>Glc2Gc</th>
      <th>Glc2Gc3Gc4Gc</th>
      <th>Glc2GroA</th>
      <th>Glc2GroA6Ac</th>
      <th>Glc2Hxo6Ac</th>
      <th>Glc2Lau3Dco</th>
      <th>Glc2Lau3Dco4P</th>
      <th>Glc2Lau3Lau4P</th>
      <th>Glc2Me</th>
      <th>Glc2Me3Me4Me</th>
      <th>Glc2Me3Me4Me6Me</th>
      <th>Glc2Me3Me4Me6S</th>
      <th>Glc2Me3Me5Me6Me-ol</th>
      <th>Glc2Me3Me6Me</th>
      <th>Glc2Me3Me6S</th>
      <th>Glc2Me4Me</th>
      <th>Glc2Me6N</th>
      <th>Glc2Myr3Myr4P</th>
      <th>Glc2NAc3NAc-aric</th>
      <th>Glc2Oco3Ac</th>
      <th>Glc2Ole6AcNCm</th>
      <th>Glc2P</th>
      <th>Glc2P3P6Ac</th>
      <th>Glc2PGro</th>
      <th>Glc2Pam</th>
      <th>Glc2Pam6AcNCm</th>
      <th>Glc2Pp3Pp6Ac</th>
      <th>Glc2S</th>
      <th>Glc2S3Me4Me6S</th>
      <th>Glc2S3Me6S</th>
      <th>Glc2S3S</th>
      <th>Glc2S3S4Me6S</th>
      <th>Glc2S3S4S</th>
      <th>Glc2S3S4S6S</th>
      <th>Glc2S3S5S6S-onic</th>
      <th>Glc2S3S6S</th>
      <th>Glc2S4S</th>
      <th>Glc2S4S6S</th>
      <th>Glc2S6SN</th>
      <th>Glc2Ste</th>
      <th>Glc2Vac6AcNCm</th>
      <th>Glc2Vac6AcNMe</th>
      <th>Glc2Vac6AcNOCm</th>
      <th>Glc3Ac</th>
      <th>Glc3Ac4Ac</th>
      <th>Glc3Ac4Ac6Ac</th>
      <th>Glc3Ac4PGro</th>
      <th>Glc3Ac6Ac</th>
      <th>Glc3F</th>
      <th>Glc3Gc</th>
      <th>Glc3Gc4Gc</th>
      <th>Glc3Lac</th>
      <th>Glc3Me</th>
      <th>Glc3Me4Pyr</th>
      <th>Glc3Me6Me</th>
      <th>Glc3Me6S</th>
      <th>Glc3N</th>
      <th>Glc3NAc</th>
      <th>Glc3P</th>
      <th>Glc3P-ol</th>
      <th>Glc3P4P</th>
      <th>Glc3P4P6Ac</th>
      <th>Glc3PEtN6PEtN</th>
      <th>Glc3PGro</th>
      <th>Glc3S</th>
      <th>Glc3S-ol</th>
      <th>Glc3S4S</th>
      <th>Glc3S4S6S</th>
      <th>Glc3S6Et</th>
      <th>Glc3S6S</th>
      <th>Glc4Ac</th>
      <th>Glc4Ac6Ac</th>
      <th>Glc4Ac6PCho</th>
      <th>Glc4Lac</th>
      <th>Glc4Me</th>
      <th>Glc4Me6Me</th>
      <th>Glc4N</th>
      <th>Glc4P</th>
      <th>Glc4PEtN</th>
      <th>Glc4PGro</th>
      <th>Glc4Pyr</th>
      <th>Glc4S</th>
      <th>Glc4S6S</th>
      <th>Glc5CF</th>
      <th>Glc5N</th>
      <th>Glc5S</th>
      <th>Glc6Ac</th>
      <th>Glc6Ac-ol</th>
      <th>Glc6Ac1Coum</th>
      <th>Glc6Ac1Fer</th>
      <th>Glc6AcGro</th>
      <th>Glc6AcGroA</th>
      <th>Glc6AcNBut</th>
      <th>Glc6AcNCm2Ole</th>
      <th>Glc6AcNCm2Pam</th>
      <th>Glc6AcNCm2Vac</th>
      <th>Glc6AcNMe2Vac</th>
      <th>Glc6AcNMeOCm</th>
      <th>Glc6AcNMeOCm2Vac</th>
      <th>Glc6AcNOCm2Vac</th>
      <th>Glc6AcOP</th>
      <th>Glc6AcOPGro</th>
      <th>Glc6AcPGro</th>
      <th>Glc6F</th>
      <th>Glc6I</th>
      <th>Glc6Me</th>
      <th>Glc6Me-onic</th>
      <th>Glc6N</th>
      <th>Glc6NAc</th>
      <th>Glc6P</th>
      <th>Glc6P-ol</th>
      <th>Glc6PCho</th>
      <th>Glc6PEtN</th>
      <th>Glc6PGro</th>
      <th>Glc6PGroA</th>
      <th>Glc6PGroAc</th>
      <th>Glc6S</th>
      <th>Glc6S-ol</th>
      <th>Glc6Thr</th>
      <th>Glc6uloN</th>
      <th>GlcA</th>
      <th>GlcA1Cer</th>
      <th>GlcA1Gro</th>
      <th>GlcA1Me2NAc</th>
      <th>GlcA1P</th>
      <th>GlcA1PGroA6N</th>
      <th>GlcA1PP</th>
      <th>GlcA1PP2NAc</th>
      <th>GlcA1PP2NAc3N</th>
      <th>GlcA1PP2NAc3NAc</th>
      <th>GlcA2Ac</th>
      <th>GlcA2Ac3Ac</th>
      <th>GlcA2Me</th>
      <th>GlcA2Me3Me</th>
      <th>GlcA2Me4Me</th>
      <th>GlcA2N</th>
      <th>GlcA2NAc</th>
      <th>GlcA2NAc3N</th>
      <th>GlcA2NAc3N6N</th>
      <th>GlcA2NAc3NAc</th>
      <th>GlcA2NAc3NAc4Ac</th>
      <th>GlcA2NAc3NAc6N</th>
      <th>GlcA2NAc4Me</th>
      <th>GlcA2Pyr</th>
      <th>GlcA2Pyr3Pyr</th>
      <th>GlcA2S</th>
      <th>GlcA2S3Ac</th>
      <th>GlcA2S3Me</th>
      <th>GlcA2S3S</th>
      <th>GlcA3Ac</th>
      <th>GlcA3Fo4Me</th>
      <th>GlcA3Lac</th>
      <th>GlcA3N</th>
      <th>GlcA3NAc</th>
      <th>GlcA3S</th>
      <th>GlcA3S6Me</th>
      <th>GlcA4Ac</th>
      <th>GlcA4Ac6Ser</th>
      <th>GlcA4Lac</th>
      <th>GlcA4Me</th>
      <th>GlcA4Me6Me</th>
      <th>GlcA4Me6N</th>
      <th>GlcA6Ac</th>
      <th>GlcA6Ala</th>
      <th>GlcA6CetLys</th>
      <th>GlcA6EtN</th>
      <th>GlcA6Gly</th>
      <th>GlcA6GroN</th>
      <th>GlcA6Lys</th>
      <th>GlcA6Me</th>
      <th>GlcA6N</th>
      <th>GlcA6S</th>
      <th>GlcA6Ser</th>
      <th>GlcA6Thr</th>
      <th>GlcA6ThrAc</th>
      <th>GlcAAlaLys</th>
      <th>GlcAGlu</th>
      <th>GlcAGro</th>
      <th>GlcAGroN</th>
      <th>GlcALys</th>
      <th>GlcAN</th>
      <th>GlcAN2But3NBut</th>
      <th>GlcAOAc</th>
      <th>GlcAOBut</th>
      <th>GlcAOEtN</th>
      <th>GlcAOLac</th>
      <th>GlcAOMe</th>
      <th>GlcAOP</th>
      <th>GlcAOPyr</th>
      <th>GlcAOS</th>
      <th>GlcASer</th>
      <th>GlcCho</th>
      <th>GlcGro</th>
      <th>GlcGroA</th>
      <th>GlcN</th>
      <th>GlcN-ol</th>
      <th>GlcN-onic</th>
      <th>GlcN1Me2S6S</th>
      <th>GlcN1N</th>
      <th>GlcN1N2Gc</th>
      <th>GlcN1P</th>
      <th>GlcN1P2Ach3Myr</th>
      <th>GlcN1P2Dco3Dco</th>
      <th>GlcN1P2Dco3Myr</th>
      <th>GlcN1P2Lau</th>
      <th>GlcN1P2Lau3Dco</th>
      <th>GlcN1P2Lau3Lau</th>
      <th>GlcN1P2Mar3Pam</th>
      <th>GlcN1P2Myr</th>
      <th>GlcN1P2Myr3Dco</th>
      <th>GlcN1P2Myr3Lau</th>
      <th>GlcN1P2Myr3Myr</th>
      <th>GlcN1P2Pam</th>
      <th>GlcN1P2Pam3Myr</th>
      <th>GlcN1P2Ste3Myr</th>
      <th>GlcN1P2Ste3Pam</th>
      <th>GlcN1P2Ste3Ste</th>
      <th>GlcN1P3N</th>
      <th>GlcN1PEtN</th>
      <th>GlcN1PEtN2Myr3Myr</th>
      <th>GlcN1PEtN2Ste3Pam</th>
      <th>GlcN1PLau3Dco</th>
      <th>GlcN1PP</th>
      <th>GlcN1PP2Lau</th>
      <th>GlcN1PP2Myr3Myr</th>
      <th>GlcN1PPEtN2Dco3Dco</th>
      <th>GlcN1PPEtN2Lau3Lau</th>
      <th>GlcN1PPEtN2Myr3Lau</th>
      <th>GlcN1PPEtN2Myr3Myr</th>
      <th>GlcN1PPEtN2Myr3NMyr</th>
      <th>GlcN1PPEtN2Ste3NPam</th>
      <th>GlcN1Ste2Myr3N</th>
      <th>GlcN1Vac</th>
      <th>GlcN2Ac</th>
      <th>GlcN2Ach3Myr4P</th>
      <th>GlcN2Ach3NPam4P</th>
      <th>GlcN2Ala</th>
      <th>GlcN2Ala3Ac</th>
      <th>GlcN2AlaAc</th>
      <th>GlcN2But</th>
      <th>GlcN2But3NFoA6N</th>
      <th>GlcN2Dco3Dco4P</th>
      <th>GlcN2Dco3Dco4PPEtN</th>
      <th>GlcN2Dco3Myr3P</th>
      <th>GlcN2Dco4P</th>
      <th>GlcN2Fo</th>
      <th>GlcN2Gc</th>
      <th>GlcN2Gly</th>
      <th>GlcN2Lau3Dco4P</th>
      <th>GlcN2Lau3Lau4P</th>
      <th>GlcN2Lau3Myr4P</th>
      <th>GlcN2Lau4P</th>
      <th>GlcN2Mar</th>
      <th>GlcN2Mar3Myr</th>
      <th>GlcN2Mar3Pam</th>
      <th>GlcN2Me</th>
      <th>GlcN2Me2Ole3Cm</th>
      <th>GlcN2Me2Ole4Cm</th>
      <th>GlcN2Me2Ole6Cm</th>
      <th>GlcN2Me3Cm4Cm6Cm</th>
      <th>GlcN2Me3Me4P</th>
      <th>GlcN2Myr</th>
      <th>GlcN2Myr3Dco</th>
      <th>GlcN2Myr3Dco4P</th>
      <th>GlcN2Myr3Lau</th>
      <th>GlcN2Myr3Lau4P</th>
      <th>GlcN2Myr3Lau4PPEtN</th>
      <th>GlcN2Myr3Myr</th>
      <th>GlcN2Myr3Myr4P</th>
      <th>GlcN2Myr3Myr4PEtN</th>
      <th>GlcN2Myr3Myr4PP</th>
      <th>GlcN2Myr3Myr4PPEtN</th>
      <th>GlcN2Myr3NLau</th>
      <th>GlcN2Myr3NMyr</th>
      <th>GlcN2Myr3NMyr4P</th>
      <th>GlcN2Myr3NMyr4PPEtN</th>
      <th>GlcN2Myr3NPam</th>
      <th>GlcN2Myr3Pam4P</th>
      <th>GlcN2Myr4P</th>
      <th>GlcN2Ole</th>
      <th>GlcN2Ole6Ac</th>
      <th>GlcN2Pam</th>
      <th>GlcN2Pam-onic</th>
      <th>GlcN2Pam3Myr</th>
      <th>GlcN2Pam3Myr-onic</th>
      <th>GlcN2Pam3Myr4P</th>
      <th>GlcN2Pam3NMyr</th>
      <th>GlcN2Pam3NMyr4P</th>
      <th>GlcN2Pam4P</th>
      <th>GlcN2Pam6Ac</th>
      <th>GlcN2S</th>
      <th>GlcN2S-ol</th>
      <th>GlcN2S3Me4Me6S</th>
      <th>GlcN2S3S</th>
      <th>GlcN2S3S6S</th>
      <th>GlcN2S4Me6S</th>
      <th>GlcN2S6S</th>
      <th>GlcN2S6S-ol</th>
      <th>GlcN2Ste</th>
      <th>GlcN2Ste-onic</th>
      <th>GlcN2Ste3Myr</th>
      <th>GlcN2Ste3Myr-onic</th>
      <th>GlcN2Ste3NMyr</th>
      <th>GlcN2Ste3Pam4P</th>
      <th>GlcN2Suc</th>
      <th>GlcN2Vac</th>
      <th>GlcN2Vac6Ac</th>
      <th>GlcN3Ac4Ac6Ac</th>
      <th>GlcN3Lau4P</th>
      <th>GlcN3N</th>
      <th>GlcN3N4P</th>
      <th>GlcN3N4PP</th>
      <th>GlcN3N4PPEtN</th>
      <th>GlcN3NMyr</th>
      <th>GlcN3S</th>
      <th>GlcN3S6S</th>
      <th>GlcN4Ac</th>
      <th>GlcN4P</th>
      <th>GlcN4P6Ac</th>
      <th>GlcN4PEtN</th>
      <th>GlcN4PP</th>
      <th>GlcN4PPEtN</th>
      <th>GlcN6Ac</th>
      <th>GlcN6Aep</th>
      <th>GlcN6Me</th>
      <th>GlcN6N</th>
      <th>GlcN6P</th>
      <th>GlcN6PCho</th>
      <th>GlcN6PEtN</th>
      <th>GlcN6S</th>
      <th>GlcNAC-ol</th>
      <th>GlcNAc</th>
      <th>GlcNAc-ol</th>
      <th>GlcNAc-onic</th>
      <th>GlcNAc1Cer</th>
      <th>GlcNAc1EtN</th>
      <th>GlcNAc1Gro</th>
      <th>GlcNAc1Me</th>
      <th>GlcNAc1Me6S</th>
      <th>GlcNAc1N</th>
      <th>GlcNAc1N-ol</th>
      <th>GlcNAc1N3N</th>
      <th>GlcNAc1N3S</th>
      <th>GlcNAc1N5CN</th>
      <th>GlcNAc1N6Me</th>
      <th>GlcNAc1N6N</th>
      <th>GlcNAc1NAc</th>
      <th>GlcNAc1Ole6Ac</th>
      <th>GlcNAc1OleOAcOCm</th>
      <th>GlcNAc1P</th>
      <th>GlcNAc1P-ol</th>
      <th>GlcNAc1P4PCho</th>
      <th>GlcNAc1PGro</th>
      <th>GlcNAc1PP</th>
      <th>GlcNAc1PP3P</th>
      <th>GlcNAc1Pam6Ac</th>
      <th>GlcNAc1PamOAcOCm</th>
      <th>GlcNAc1Prop</th>
      <th>GlcNAc1S</th>
      <th>GlcNAc1Ser</th>
      <th>GlcNAc1Thr</th>
      <th>GlcNAc1VacOAc</th>
      <th>GlcNAc1VacOAcOCm</th>
      <th>GlcNAc2Ala</th>
      <th>GlcNAc2GroA6P</th>
      <th>GlcNAc3Ac</th>
      <th>GlcNAc3Ac4Ac</th>
      <th>GlcNAc3Ac4Ac6Ac</th>
      <th>GlcNAc3Ac4PGro</th>
      <th>GlcNAc3Ac4Pyr</th>
      <th>GlcNAc3Ac6Ac</th>
      <th>GlcNAc3Lac</th>
      <th>GlcNAc3Me</th>
      <th>GlcNAc3N</th>
      <th>GlcNAc3N4Ac6N</th>
      <th>GlcNAc3NAc</th>
      <th>GlcNAc3NAc4Ac</th>
      <th>GlcNAc3Prop</th>
      <th>GlcNAc3S</th>
      <th>GlcNAc3S-ol</th>
      <th>GlcNAc3S4S6S</th>
      <th>GlcNAc3S6S</th>
      <th>GlcNAc4Ac</th>
      <th>GlcNAc4Dhpa</th>
      <th>GlcNAc4F</th>
      <th>GlcNAc4Lac</th>
      <th>GlcNAc4Lac6Ac</th>
      <th>GlcNAc4Me</th>
      <th>GlcNAc4Me6Me</th>
      <th>GlcNAc4N</th>
      <th>GlcNAc4NAc</th>
      <th>GlcNAc4P</th>
      <th>GlcNAc4P-ol</th>
      <th>GlcNAc4PCho6P</th>
      <th>GlcNAc4PGro</th>
      <th>GlcNAc4Pyr</th>
      <th>GlcNAc6AEP</th>
      <th>GlcNAc6Ac</th>
      <th>GlcNAc6Aep</th>
      <th>GlcNAc6Cl</th>
      <th>GlcNAc6Gc</th>
      <th>GlcNAc6I</th>
      <th>GlcNAc6Me</th>
      <th>GlcNAc6N</th>
      <th>GlcNAc6NAc</th>
      <th>GlcNAc6P</th>
      <th>GlcNAc6P-ol</th>
      <th>GlcNAc6PCho</th>
      <th>GlcNAc6PEtN</th>
      <th>GlcNAc6PEtNAc</th>
      <th>GlcNAc6PEtg</th>
      <th>GlcNAc6PGro</th>
      <th>GlcNAc6Pyr</th>
      <th>GlcNAc6S</th>
      <th>GlcNAc6S-ol</th>
      <th>GlcNAcA</th>
      <th>GlcNAcA3Ac</th>
      <th>GlcNAcA3Ac4NAc</th>
      <th>GlcNAcA3N</th>
      <th>GlcNAcA3NAc</th>
      <th>GlcNAcA3NAc4Ac</th>
      <th>GlcNAcA3NAc6N</th>
      <th>GlcNAcA3NAlaFo6N</th>
      <th>GlcNAcA3NAm</th>
      <th>GlcNAcA3NBut</th>
      <th>GlcNAcA3NFoAla6N</th>
      <th>GlcNAcA3NSucAc6N</th>
      <th>GlcNAcA3S</th>
      <th>GlcNAcA6Ala</th>
      <th>GlcNAcA6Gly</th>
      <th>GlcNAcAAla</th>
      <th>GlcNAcAN</th>
      <th>GlcNAcANAla</th>
      <th>GlcNAcANAlaAc</th>
      <th>GlcNAcANAlaFo</th>
      <th>GlcNAcAOAc</th>
      <th>GlcNAcAOMe</th>
      <th>GlcNAcAla</th>
      <th>GlcNAcGlu</th>
      <th>GlcNAcGly</th>
      <th>GlcNAcGro</th>
      <th>GlcNAcN</th>
      <th>GlcNAcN-ol</th>
      <th>GlcNAcNAla</th>
      <th>GlcNAcNAlaFo</th>
      <th>GlcNAcNAmA</th>
      <th>GlcNAcOAc</th>
      <th>GlcNAcOAc1Vac</th>
      <th>GlcNAcOAcNAla</th>
      <th>GlcNAcOAcOCm1Ole</th>
      <th>GlcNAcOAcOCm1Pam</th>
      <th>GlcNAcOAcOCm1Vac</th>
      <th>GlcNAcOAcOLac</th>
      <th>GlcNAcOAcOS-ol</th>
      <th>GlcNAcOLac</th>
      <th>GlcNAcOLacAla</th>
      <th>GlcNAcOLacGro</th>
      <th>GlcNAcOMe</th>
      <th>GlcNAcOP</th>
      <th>GlcNAcOPCho</th>
      <th>GlcNAcOPEtN</th>
      <th>GlcNAcOPEtg</th>
      <th>GlcNAcOPGro</th>
      <th>GlcNAcOPGroA</th>
      <th>GlcNAcOPOAch</th>
      <th>GlcNAcOPyr</th>
      <th>GlcNAcOS</th>
      <th>GlcNAcOS-ol</th>
      <th>GlcNAcPCho</th>
      <th>GlcNAcPGro</th>
      <th>GlcNAcPGroA</th>
      <th>GlcNAm</th>
      <th>GlcNAmA</th>
      <th>GlcNBut</th>
      <th>GlcNButOAc</th>
      <th>GlcNCm1OleOCm</th>
      <th>GlcNCm1Vac</th>
      <th>GlcNCm1VacOCm</th>
      <th>GlcNCmOCm</th>
      <th>GlcNCmOCm1Ole</th>
      <th>GlcNCmOCm1Vac</th>
      <th>GlcNGc</th>
      <th>GlcNGly</th>
      <th>GlcNMe</th>
      <th>GlcNMe1PamOCm</th>
      <th>GlcNMe1Vac</th>
      <th>GlcNMe1VacOCm</th>
      <th>GlcNMe2Vac</th>
      <th>GlcNMe2Vac3Cm4Cm</th>
      <th>GlcNMeOCm</th>
      <th>GlcNMeOCm1Pam</th>
      <th>GlcNMeOCm1Vac</th>
      <th>GlcNMeOCm2Pam</th>
      <th>GlcNMeOCm2Vac</th>
      <th>GlcNMeOCmOSte</th>
      <th>GlcNMeOSte</th>
      <th>GlcNOAc</th>
      <th>GlcNOCm1Vac</th>
      <th>GlcNOCmOAch</th>
      <th>GlcNOMar</th>
      <th>GlcNOMyr</th>
      <th>GlcNOP</th>
      <th>GlcNOPEtN</th>
      <th>GlcNOPyr</th>
      <th>GlcNP3NFoA6N</th>
      <th>GlcNProp</th>
      <th>GlcNS3S</th>
      <th>GlcNS3S6S</th>
      <th>GlcNS6S</th>
      <th>GlcOAc</th>
      <th>GlcOBz</th>
      <th>GlcOCm2Vac6AcNMe</th>
      <th>GlcOCm6AcNMe</th>
      <th>GlcOEtNN</th>
      <th>GlcOGly</th>
      <th>GlcOLac</th>
      <th>GlcOMal</th>
      <th>GlcOMe</th>
      <th>GlcOMe-ol</th>
      <th>GlcOMeN</th>
      <th>GlcOMeNOMyr</th>
      <th>GlcOMeOPyr</th>
      <th>GlcOP</th>
      <th>GlcOP-ol</th>
      <th>GlcOP1Ole</th>
      <th>GlcOPCho</th>
      <th>GlcOPChoGro</th>
      <th>GlcOPEtN</th>
      <th>GlcOPEtNN</th>
      <th>GlcOPGro</th>
      <th>GlcOPN</th>
      <th>GlcOPN1Pam</th>
      <th>GlcOPNOMyr</th>
      <th>GlcOPPEtN</th>
      <th>GlcOPyr</th>
      <th>GlcOS</th>
      <th>GlcOSN</th>
      <th>GlcOSNMeOCm</th>
      <th>GlcOSin</th>
      <th>GlcPCho</th>
      <th>GlcPChoGro</th>
      <th>GlcPGro</th>
      <th>GlcS</th>
      <th>GlcThr</th>
      <th>Glcf</th>
      <th>Gul</th>
      <th>Gul-onic</th>
      <th>GulA</th>
      <th>GulN</th>
      <th>GulNAc</th>
      <th>GulNAc1N</th>
      <th>GulNAc1N6Me</th>
      <th>GulNAcA</th>
      <th>GulNAcAN</th>
      <th>GulNAcANAm</th>
      <th>Hep</th>
      <th>Hep3Me6Me</th>
      <th>Hep4P</th>
      <th>HepOP</th>
      <th>Hex</th>
      <th>Hex-ol</th>
      <th>HexA</th>
      <th>HexA2NAc3NAc</th>
      <th>HexA2S</th>
      <th>HexA6S</th>
      <th>HexN</th>
      <th>HexN2Me</th>
      <th>HexNAc</th>
      <th>HexNAc-ol</th>
      <th>HexNAcOPCho</th>
      <th>HexNAcOPEtN</th>
      <th>HexNAcOS</th>
      <th>HexOAc</th>
      <th>HexOMe</th>
      <th>HexOMeOFo</th>
      <th>HexOS</th>
      <th>Hexf</th>
      <th>Ido</th>
      <th>Ido-onic</th>
      <th>Ido2S</th>
      <th>IdoA</th>
      <th>IdoA1Me2S</th>
      <th>IdoA1PP</th>
      <th>IdoA2Ac3Ac</th>
      <th>IdoA2Me3Me</th>
      <th>IdoA2S</th>
      <th>IdoA2S3Ac</th>
      <th>IdoA2S3Et</th>
      <th>IdoA2S3Me</th>
      <th>IdoA2S3S</th>
      <th>IdoA2S4Me</th>
      <th>IdoA2S6Me</th>
      <th>IdoA2S6S</th>
      <th>IdoA3S</th>
      <th>IdoAOS</th>
      <th>IdoN</th>
      <th>IdoN6N</th>
      <th>IdoNAc</th>
      <th>IdoNAc1N</th>
      <th>IdoNAc6NAc</th>
      <th>Ins</th>
      <th>Ins3PEtN</th>
      <th>Kdn</th>
      <th>Kdn1N</th>
      <th>Kdn2P</th>
      <th>Kdn5Ac</th>
      <th>Kdn7Pyr</th>
      <th>Kdn8Me</th>
      <th>Kdn9Ac</th>
      <th>Kdn9Me</th>
      <th>KdnNAc</th>
      <th>KdnOMe</th>
      <th>Kdo</th>
      <th>Kdo-ol</th>
      <th>Kdo1Me</th>
      <th>Kdo1N</th>
      <th>Kdo2Me</th>
      <th>Kdo2P</th>
      <th>Kdo2P8N</th>
      <th>Kdo2PGro</th>
      <th>Kdo4Ac</th>
      <th>Kdo4Ac5Ac</th>
      <th>Kdo4Ac5S</th>
      <th>Kdo4P</th>
      <th>Kdo4P8P</th>
      <th>Kdo4PPEtN</th>
      <th>Kdo4PPEtN8N</th>
      <th>Kdo5Me</th>
      <th>Kdo5P</th>
      <th>Kdo5PGro</th>
      <th>Kdo5S</th>
      <th>Kdo7Ac</th>
      <th>Kdo7Me</th>
      <th>Kdo7P</th>
      <th>Kdo7PEtN</th>
      <th>Kdo7Pyr</th>
      <th>Kdo8Ac</th>
      <th>Kdo8P</th>
      <th>Kdo8PEtN</th>
      <th>Kdo8Pp</th>
      <th>KdoN</th>
      <th>KdoOAc</th>
      <th>KdoOMe</th>
      <th>KdoOP</th>
      <th>KdoOPEtN</th>
      <th>KdoOPN</th>
      <th>KdoOPOEtN</th>
      <th>KdoOPPEtN</th>
      <th>KdoOPPEtNN</th>
      <th>Kdof</th>
      <th>Ko</th>
      <th>Ko2Me</th>
      <th>KoOMe</th>
      <th>KoOPEtN</th>
      <th>L-2dThrPen4N</th>
      <th>L-2dThrPen4NMe</th>
      <th>L-4dEry-ol</th>
      <th>L-4dEryHexAN4en</th>
      <th>L-4dThrHex4en</th>
      <th>L-4dThrHexA4en</th>
      <th>L-4dThrHexA4en6N</th>
      <th>L-4dThrHexA4enAla</th>
      <th>L-4dThrHexAN4en</th>
      <th>L-4dThrHexNAcA4en6N</th>
      <th>L-4dThre-ol</th>
      <th>L-6dAll</th>
      <th>L-6dAraHex</th>
      <th>L-6dAraHexOMe</th>
      <th>L-6dGalHep</th>
      <th>L-6dGalHepOP</th>
      <th>L-6dGalHepf</th>
      <th>L-6dGul</th>
      <th>L-6dGulHep</th>
      <th>L-6dGulHepOMe</th>
      <th>L-6dGulHepOP</th>
      <th>L-6dGulHepf</th>
      <th>L-6dXylHexNAc4Ulo</th>
      <th>L-All</th>
      <th>L-Dig</th>
      <th>L-Dig3Me</th>
      <th>L-Dig4Me</th>
      <th>L-DigOMe</th>
      <th>L-Ery-ol</th>
      <th>L-Fru</th>
      <th>L-Gal</th>
      <th>L-Gal-onic</th>
      <th>L-Gal1PP</th>
      <th>L-Gal2S</th>
      <th>L-Gal3S</th>
      <th>L-Gal6S</th>
      <th>L-GalA2N</th>
      <th>L-GalA2NAc</th>
      <th>L-GalA2NAc3NAc</th>
      <th>L-GalA2NAc4Ac</th>
      <th>L-GalA3Me</th>
      <th>L-GalANAm3Ac</th>
      <th>L-GalAOAcNAm</th>
      <th>L-GalNAc</th>
      <th>L-GalNAc-onic</th>
      <th>L-GalNAcA</th>
      <th>L-GalNAcA3Ac</th>
      <th>L-GalNAcAN</th>
      <th>L-GalNAcAOAc</th>
      <th>L-GalNAmA</th>
      <th>L-GalOS</th>
      <th>L-Glc</th>
      <th>L-Glc2S3S</th>
      <th>L-Glc3Me</th>
      <th>L-Glc3Me6Me</th>
      <th>L-GlcA</th>
      <th>L-GlcN2Me</th>
      <th>L-GlcN2Me3P</th>
      <th>L-GlcNAc</th>
      <th>L-GlcOMe</th>
      <th>L-Gul</th>
      <th>L-Gul-onic</th>
      <th>L-Gul1PP</th>
      <th>L-Gul4NAc5NAc-onic</th>
      <th>L-GulA</th>
      <th>L-GulA2N</th>
      <th>L-GulA2NAc</th>
      <th>L-GulA2NAc3Et</th>
      <th>L-GulA2NAc3N</th>
      <th>L-GulA2NAc3NAc</th>
      <th>L-GulA2NAc3NAm</th>
      <th>L-GulA2S</th>
      <th>L-GulAN</th>
      <th>L-GulNAc</th>
      <th>L-GulNAc3Ac</th>
      <th>L-GulNAcA</th>
      <th>L-GulNAcA3Ac6Gly</th>
      <th>L-GulNAcA3NAc</th>
      <th>L-GulNAcA3NAm</th>
      <th>L-GulNAcA6Gly</th>
      <th>L-GulNAcAN</th>
      <th>L-GulNAcANAm</th>
      <th>L-GulNAcANEtN</th>
      <th>L-GulNAcAOAc</th>
      <th>L-GulNAcAOAcN</th>
      <th>L-GulNAcAOEtN</th>
      <th>L-Lyx</th>
      <th>L-Man</th>
      <th>L-Man-ol</th>
      <th>L-Man2Me4Me</th>
      <th>L-Man3Me</th>
      <th>L-Man6Me</th>
      <th>L-ManNAc</th>
      <th>L-Oli</th>
      <th>L-Oli3CMe</th>
      <th>L-Oli3CMe4Ac</th>
      <th>L-Oli3CNMe</th>
      <th>L-Oli3Me</th>
      <th>L-Oli3Me4Ac</th>
      <th>L-Oli4Me</th>
      <th>L-Psif</th>
      <th>L-Qui</th>
      <th>L-Qui2Me4N</th>
      <th>L-Qui3Ac4Ac</th>
      <th>L-Qui3NAc</th>
      <th>L-Qui3NAc4Me</th>
      <th>L-Qui4N</th>
      <th>L-QuiN</th>
      <th>L-QuiNAc</th>
      <th>L-QuiNAc4P</th>
      <th>L-QuiNAcOMe</th>
      <th>L-QuiNAcOP</th>
      <th>L-Ribf</th>
      <th>L-Tal</th>
      <th>L-TalNAc</th>
      <th>L-Xyl</th>
      <th>L-Xyl1N4Me</th>
      <th>L-Xyl1N4Me-onic</th>
      <th>L-Xyl3Me</th>
      <th>L-XylOMe</th>
      <th>LDIdoHep</th>
      <th>LDIdoHepPro</th>
      <th>LDManHep</th>
      <th>LDManHep1Me4P</th>
      <th>LDManHep2Ac</th>
      <th>LDManHep2Gly4P</th>
      <th>LDManHep2P4P</th>
      <th>LDManHep2PPEtN</th>
      <th>LDManHep2PPEtN4P</th>
      <th>LDManHep3P</th>
      <th>LDManHep3PEtN</th>
      <th>LDManHep4P</th>
      <th>LDManHep4P6Gly</th>
      <th>LDManHep4P6P</th>
      <th>LDManHep4PEtN</th>
      <th>LDManHep4PEtN7PEtN</th>
      <th>LDManHep4POGly</th>
      <th>LDManHep4PPEtN</th>
      <th>LDManHep6P</th>
      <th>LDManHep6P7Cm</th>
      <th>LDManHep6PEtN</th>
      <th>LDManHep6PPEtN</th>
      <th>LDManHep7P</th>
      <th>LDManHep7PEtN</th>
      <th>LDManHepGly</th>
      <th>LDManHepGroN</th>
      <th>LDManHepOAc</th>
      <th>LDManHepOCm</th>
      <th>LDManHepOEtN</th>
      <th>LDManHepOGly</th>
      <th>LDManHepOMe</th>
      <th>LDManHepOP</th>
      <th>LDManHepOPEtN</th>
      <th>LDManHepOPGroA</th>
      <th>LDManHepOPOCm</th>
      <th>LDManHepOPOMe</th>
      <th>LDManHepOPOPEtN</th>
      <th>LDManHepOPOPPEtN</th>
      <th>LDManHepOPPEtN</th>
      <th>LDManHepPGroA</th>
      <th>Leg</th>
      <th>Leg2P5Ac7Ac</th>
      <th>Leg4Ac5Ac7Ac</th>
      <th>Leg5Ac</th>
      <th>Leg5Ac7Ac</th>
      <th>Leg5Ac7Ala</th>
      <th>Leg5Ac7But</th>
      <th>Leg5Am7Ac</th>
      <th>Leg5But7Ac</th>
      <th>Leg5Fo7Ac</th>
      <th>LegNAc</th>
      <th>LegNAcAla</th>
      <th>LegNAcNAla</th>
      <th>LegNAcNAm</th>
      <th>LegNAcNBut</th>
      <th>LegNFo</th>
      <th>Lyx</th>
      <th>Lyx-ol</th>
      <th>Lyx2Me</th>
      <th>Lyx2N-ol</th>
      <th>Lyxf</th>
      <th>Lyxf3CFo</th>
      <th>Man</th>
      <th>Man-ol</th>
      <th>Man-onic</th>
      <th>Man1Cer</th>
      <th>Man1Et</th>
      <th>Man1EtN</th>
      <th>Man1Me</th>
      <th>Man1Me2Et</th>
      <th>Man1Me2S3S6S</th>
      <th>Man1Me4Me</th>
      <th>Man1N</th>
      <th>Man1N-ol</th>
      <th>Man1P</th>
      <th>Man1P-ol</th>
      <th>Man1PEtN-ol</th>
      <th>Man1PP</th>
      <th>Man1Prop</th>
      <th>Man1S</th>
      <th>Man1S2Ac3Ac4Ac</th>
      <th>Man1S2S4S6S</th>
      <th>Man1S3S4S6S</th>
      <th>Man1Ser</th>
      <th>Man2Ac</th>
      <th>Man2Ac3Ac4Ac</th>
      <th>Man2Ac3Ac4Ac6Ac</th>
      <th>Man2Ac4Ac6Ac</th>
      <th>Man2Ac6Ac</th>
      <th>Man2Br</th>
      <th>Man2But</th>
      <th>Man2But6Ac</th>
      <th>Man2Cl6Cl</th>
      <th>Man2Et</th>
      <th>Man2F</th>
      <th>Man2Me</th>
      <th>Man2Me4N</th>
      <th>Man2Me6Me</th>
      <th>Man2N</th>
      <th>Man2N-ol</th>
      <th>Man2Oco3Hxo4Hxo6Hxo</th>
      <th>Man2Oco3Oco4Oco6Oco</th>
      <th>Man2Oco6Ac</th>
      <th>Man2P</th>
      <th>Man2PEtN</th>
      <th>Man2PMe</th>
      <th>Man2S</th>
      <th>Man2S3S4S6P</th>
      <th>Man2S3S6S</th>
      <th>Man2S4S6S</th>
      <th>Man2S6S</th>
      <th>Man3Ac</th>
      <th>Man3CMe</th>
      <th>Man3CN</th>
      <th>Man3Et</th>
      <th>Man3Fo</th>
      <th>Man3Me</th>
      <th>Man3N</th>
      <th>Man3P</th>
      <th>Man3PGro</th>
      <th>Man3PMe</th>
      <th>Man3S</th>
      <th>Man3S4S6S</th>
      <th>Man3S6S</th>
      <th>Man4Ac</th>
      <th>Man4Ac6Ac</th>
      <th>Man4CN</th>
      <th>Man4Dhpa</th>
      <th>Man4Lac</th>
      <th>Man4Me</th>
      <th>Man4Me6Me</th>
      <th>Man4N</th>
      <th>Man4Pyr</th>
      <th>Man4S</th>
      <th>Man4Suc</th>
      <th>Man5P-ol</th>
      <th>Man6AEP</th>
      <th>Man6Ac</th>
      <th>Man6Aep</th>
      <th>Man6F</th>
      <th>Man6Me</th>
      <th>Man6N</th>
      <th>Man6P</th>
      <th>Man6P-ol</th>
      <th>Man6PCho</th>
      <th>Man6PEtN</th>
      <th>Man6S</th>
      <th>ManA</th>
      <th>ManA1PP</th>
      <th>ManA1PP2NAc</th>
      <th>ManA1PP2NAc3NAc</th>
      <th>ManA2Ac</th>
      <th>ManA2Ac3Ac</th>
      <th>ManA2NAc</th>
      <th>ManA2NAc3N</th>
      <th>ManA2NAc3NAc</th>
      <th>ManA2NAc3NAc6N</th>
      <th>ManA2NAc3NAm</th>
      <th>ManA2NAc6P</th>
      <th>ManA6Me</th>
      <th>ManAOAc</th>
      <th>ManN</th>
      <th>ManN-ol</th>
      <th>ManN-onic</th>
      <th>ManN1N-ol</th>
      <th>ManN2But</th>
      <th>ManN3N</th>
      <th>ManNAc</th>
      <th>ManNAc-ol</th>
      <th>ManNAc1Me</th>
      <th>ManNAc1Me3Ac</th>
      <th>ManNAc1N</th>
      <th>ManNAc1P</th>
      <th>ManNAc1P3Ac</th>
      <th>ManNAc1P3Ac4Ac</th>
      <th>ManNAc1P4Ac</th>
      <th>ManNAc1PP</th>
      <th>ManNAc2NAc</th>
      <th>ManNAc2NAc6Thr</th>
      <th>ManNAc3Ac</th>
      <th>ManNAc4Ac</th>
      <th>ManNAc4Ac6Ac</th>
      <th>ManNAc4Lac</th>
      <th>ManNAc4P</th>
      <th>ManNAc4PGroA</th>
      <th>ManNAc4Pyr</th>
      <th>ManNAc6Ac</th>
      <th>ManNAc6PEtN</th>
      <th>ManNAcA</th>
      <th>ManNAcA1Gro3NAc</th>
      <th>ManNAcA2NAc</th>
      <th>ManNAcA2NAc4Me</th>
      <th>ManNAcA3NAc</th>
      <th>ManNAcA3NAc6Ala</th>
      <th>ManNAcA3NAc6N</th>
      <th>ManNAcA3NAm</th>
      <th>ManNAcA3NAm6Thr</th>
      <th>ManNAcA4Ac</th>
      <th>ManNAcA4Me6N</th>
      <th>ManNAcA6Thr</th>
      <th>ManNAcAAla</th>
      <th>ManNAcAN</th>
      <th>ManNAcANAm</th>
      <th>ManNAcANEtN</th>
      <th>ManNAcANOOrn</th>
      <th>ManNAcAOAc</th>
      <th>ManNAcASer</th>
      <th>ManNAcGroA</th>
      <th>ManNAcOAc</th>
      <th>ManNAcOMe</th>
      <th>ManNAcOPGro</th>
      <th>ManNAcOPyr</th>
      <th>ManNAcPGro</th>
      <th>ManNOPGro</th>
      <th>ManNPGro</th>
      <th>ManOAc</th>
      <th>ManOAcN</th>
      <th>ManOAcOMe</th>
      <th>ManOAcOPyr</th>
      <th>ManOEtN</th>
      <th>ManOLac</th>
      <th>ManOMe</th>
      <th>ManOP</th>
      <th>ManOP-ol</th>
      <th>ManOPCho</th>
      <th>ManOPEtN</th>
      <th>ManOPOMe</th>
      <th>ManOPOPyr-ol</th>
      <th>ManOPyr</th>
      <th>ManOS</th>
      <th>ManPMe</th>
      <th>Manf</th>
      <th>Manf1Me</th>
      <th>Manf1Me5P</th>
      <th>Monosaccharide</th>
      <th>Mur</th>
      <th>MurN</th>
      <th>MurNAc</th>
      <th>MurNAc-ol</th>
      <th>MurNAc1Me</th>
      <th>MurNAc1PP</th>
      <th>MurNAc6Ac</th>
      <th>MurNAc8Ala</th>
      <th>MurNAcAla</th>
      <th>MurNAcOP</th>
      <th>MurNAcSer</th>
      <th>Neu</th>
      <th>Neu1Me4Ac5Ac7Ac8Ac9Ac</th>
      <th>Neu1Me5Ac</th>
      <th>Neu1N5Ac</th>
      <th>Neu1N5Gc</th>
      <th>Neu1NMe5Ac</th>
      <th>Neu2P5Ac</th>
      <th>Neu2P5Gc</th>
      <th>Neu4Ac</th>
      <th>Neu4Ac5Ac</th>
      <th>Neu4Ac5Ac6Ac</th>
      <th>Neu4Ac5Ac7Ac</th>
      <th>Neu4Ac5Ac7Ac8Ac9Ac</th>
      <th>Neu4Ac5Ac9Ac</th>
      <th>Neu4Ac5Gc</th>
      <th>Neu4Ac7Ac9Ac</th>
      <th>Neu4Ac9Ac</th>
      <th>Neu4Gc5Ac</th>
      <th>Neu4Me5Ac</th>
      <th>Neu4Me5Ac9Me</th>
      <th>Neu4NAc5Ac</th>
      <th>Neu5Ac</th>
      <th>Neu5Ac6Ac</th>
      <th>Neu5Ac7Ac</th>
      <th>Neu5Ac7Ac8Ac</th>
      <th>Neu5Ac7Ac9Ac</th>
      <th>Neu5Ac8Ac</th>
      <th>Neu5Ac8Me</th>
      <th>Neu5Ac8S</th>
      <th>Neu5Ac9Ac</th>
      <th>Neu5Ac9Me</th>
      <th>Neu5Ac9N</th>
      <th>Neu5Ac9NAc</th>
      <th>Neu5AcNAc</th>
      <th>Neu5AcOAc</th>
      <th>Neu5AcOMe</th>
      <th>Neu5AcOS</th>
      <th>Neu5Fo</th>
      <th>Neu5Gc</th>
      <th>Neu5Gc7Ac</th>
      <th>Neu5Gc8Me</th>
      <th>Neu5Gc8S</th>
      <th>Neu5Gc9Ac</th>
      <th>Neu5Gc9Me</th>
      <th>Neu5GcOAc</th>
      <th>Neu5GcOLac</th>
      <th>Neu5GcOMe</th>
      <th>Neu5GcOS</th>
      <th>Neu5Pp</th>
      <th>Neu7Ac9Ac</th>
      <th>Neu8Me</th>
      <th>Neu9Ac</th>
      <th>NeuNAc</th>
      <th>Oli</th>
      <th>Oli1Me</th>
      <th>Oli3CMe</th>
      <th>Oli3Me</th>
      <th>Oli3N</th>
      <th>Oli3NAc</th>
      <th>Oli4Me</th>
      <th>Par</th>
      <th>Par1PP</th>
      <th>Parf</th>
      <th>Pau3Me</th>
      <th>Pau3Me7Ac</th>
      <th>Pau3Me7But</th>
      <th>Pau3Me7Pp</th>
      <th>Pau3Me7Vl</th>
      <th>Pen</th>
      <th>PenOMe</th>
      <th>Penf</th>
      <th>PenfOMe</th>
      <th>PerNAc</th>
      <th>Pse</th>
      <th>Pse2Gro5Ac7Ac</th>
      <th>Pse2P5Ac7Ac</th>
      <th>Pse4Ac5Ac7Ac</th>
      <th>Pse4Ac5Ac7But</th>
      <th>Pse5Ac</th>
      <th>Pse5Ac7Ac</th>
      <th>Pse5Ac7AcNBut</th>
      <th>Pse5Ac7AcOBut</th>
      <th>Pse5Ac7But</th>
      <th>Pse5Ac7Fo</th>
      <th>Pse5Am7Gc</th>
      <th>Pse5Am7Gra</th>
      <th>Pse5Am7GroA</th>
      <th>Pse5But7Ac</th>
      <th>Pse5But7Fo</th>
      <th>Pse7Fo</th>
      <th>PseNAc</th>
      <th>PseNAcNAm</th>
      <th>PseNAcNBut</th>
      <th>PseNAcNFo</th>
      <th>PseNAcNGro</th>
      <th>PseNAcOAcNBut</th>
      <th>PseNAcOBut</th>
      <th>PseNButNFo</th>
      <th>Psif</th>
      <th>Qui</th>
      <th>Qui-ol</th>
      <th>Qui2F</th>
      <th>Qui2Me4N</th>
      <th>Qui2Me4NAc</th>
      <th>Qui2Me4NBut</th>
      <th>Qui2N6S</th>
      <th>Qui2NAlaAc4NAlaAc</th>
      <th>Qui2NBut4NBut</th>
      <th>Qui2S3NBut</th>
      <th>Qui3N</th>
      <th>Qui3NAc</th>
      <th>Qui3NAc-ol</th>
      <th>Qui3NAlaAc</th>
      <th>Qui3NBut</th>
      <th>Qui3NFo</th>
      <th>Qui3NSerAc</th>
      <th>Qui3NThrAc</th>
      <th>Qui4CN</th>
      <th>Qui4N</th>
      <th>Qui4NAc</th>
      <th>Qui4NAlaAc</th>
      <th>Qui4NAlaBut</th>
      <th>Qui4NAlaLac</th>
      <th>Qui4NAspAc</th>
      <th>Qui4NBut</th>
      <th>Qui4NButAla</th>
      <th>Qui4NFo</th>
      <th>Qui4NGlyAc</th>
      <th>Qui4NHSerAc</th>
      <th>Qui4NHSerBut</th>
      <th>Qui4NMe</th>
      <th>Qui4NSerAc</th>
      <th>Qui6S</th>
      <th>QuiN</th>
      <th>QuiNAc</th>
      <th>QuiNAc-ol</th>
      <th>QuiNAc1Gro</th>
      <th>QuiNAc1Gro4N</th>
      <th>QuiNAc1Me4NAc</th>
      <th>QuiNAc1N</th>
      <th>QuiNAc2Ac4Ac</th>
      <th>QuiNAc3Ac4Ac</th>
      <th>QuiNAc3NAc</th>
      <th>QuiNAc4Ac</th>
      <th>QuiNAc4Me</th>
      <th>QuiNAc4N</th>
      <th>QuiNAc4NAc</th>
      <th>QuiNAc4NBut</th>
      <th>QuiNAc4NButGro</th>
      <th>QuiNAc4NGroA</th>
      <th>QuiNAc4NHex</th>
      <th>QuiNAcGro</th>
      <th>QuiNAcN</th>
      <th>QuiNAcNAlaAc</th>
      <th>QuiNAcNAm</th>
      <th>QuiNAcNAspAc</th>
      <th>QuiNAcNBut</th>
      <th>QuiNAcOAc</th>
      <th>QuiNAcOBut</th>
      <th>QuiNAcOMe</th>
      <th>QuiNAcOP</th>
      <th>QuiNAcOPGro</th>
      <th>QuiNAcPGro</th>
      <th>QuiNAla</th>
      <th>QuiNAlaAc</th>
      <th>QuiNAlaAcGro</th>
      <th>QuiNAlaButGro</th>
      <th>QuiNAspAc</th>
      <th>QuiNBut</th>
      <th>QuiNButAla</th>
      <th>QuiNButOMe</th>
      <th>QuiNFo</th>
      <th>QuiNGlyAc</th>
      <th>QuiNHseGro</th>
      <th>QuiNLac</th>
      <th>QuiNMal</th>
      <th>QuiNMe3Lac</th>
      <th>QuiNSerAc</th>
      <th>QuiNThrAc</th>
      <th>QuiOMe</th>
      <th>QuiOMeN</th>
      <th>Rha</th>
      <th>Rha-ol</th>
      <th>Rha1Dco</th>
      <th>Rha1EtN</th>
      <th>Rha1Fer</th>
      <th>Rha1Gro</th>
      <th>Rha1Gro3Me</th>
      <th>Rha1Gro3PEtN</th>
      <th>Rha1Me</th>
      <th>Rha1N</th>
      <th>Rha1P</th>
      <th>Rha1PP</th>
      <th>Rha1Prop</th>
      <th>Rha2Ac</th>
      <th>Rha2Ac3Ac</th>
      <th>Rha2Ac3Ac4Ac</th>
      <th>Rha2Ac3Lac</th>
      <th>Rha2Ac3Me</th>
      <th>Rha2Ac3PCho</th>
      <th>Rha2Ac4Ac</th>
      <th>Rha2Cl</th>
      <th>Rha2Gro</th>
      <th>Rha2Me</th>
      <th>Rha2Me3Me</th>
      <th>Rha2Me3Me4Me</th>
      <th>Rha2Me4Bz</th>
      <th>Rha2Me4Me</th>
      <th>Rha2PCho</th>
      <th>Rha2S</th>
      <th>Rha2S3S4S</th>
      <th>Rha3Ac</th>
      <th>Rha3Ac4Ac</th>
      <th>Rha3Lac</th>
      <th>Rha3Me</th>
      <th>Rha3Me4Me</th>
      <th>Rha3PEtN</th>
      <th>Rha3PEtN4Ac</th>
      <th>Rha3PGro</th>
      <th>Rha3PMe</th>
      <th>Rha3Pyr</th>
      <th>Rha3S</th>
      <th>Rha4Ac</th>
      <th>Rha4Me</th>
      <th>Rha4PGro</th>
      <th>RhaCMe</th>
      <th>RhaGro</th>
      <th>RhaGroA</th>
      <th>RhaNAc</th>
      <th>RhaNAc3NAc</th>
      <th>RhaNAc3NAc4Ac</th>
      <th>RhaNAc3NFo</th>
      <th>RhaNAcNBut</th>
      <th>RhaNAcOAc</th>
      <th>RhaNPro</th>
      <th>RhaOAc</th>
      <th>RhaOAcOLac</th>
      <th>RhaOAcOMe</th>
      <th>RhaOBut</th>
      <th>RhaOLac</th>
      <th>RhaOMe</th>
      <th>RhaOMeCMeNLac</th>
      <th>RhaOMeCMeOFo</th>
      <th>RhaOP</th>
      <th>RhaOPEtN</th>
      <th>RhaOPGro</th>
      <th>RhaOPOMe</th>
      <th>RhaOPyr</th>
      <th>RhaOS</th>
      <th>RhaPGro</th>
      <th>Rhaf</th>
      <th>Rib</th>
      <th>Rib-ol</th>
      <th>Rib1N5PP-ol</th>
      <th>Rib1P</th>
      <th>Rib1P-ol</th>
      <th>Rib1P2Ala3Ala4Ala-ol</th>
      <th>Rib2Ac3Ac4Ac</th>
      <th>Rib2Ac5P-ol</th>
      <th>Rib2Ala5P-ol</th>
      <th>Rib3Ac5P-ol</th>
      <th>Rib3P-ol</th>
      <th>Rib4Ac5P-ol</th>
      <th>Rib5P</th>
      <th>Rib5P-ol</th>
      <th>Rib5PP-ol</th>
      <th>RibOAc</th>
      <th>RibOAcOP-ol</th>
      <th>RibOP-ol</th>
      <th>RibOPEtN-ol</th>
      <th>RibOPGro-ol</th>
      <th>RibOPPGro-ol</th>
      <th>RibPGro-ol</th>
      <th>Ribf</th>
      <th>Ribf-uronic</th>
      <th>Ribf1N</th>
      <th>Ribf1N2P</th>
      <th>Ribf1N5P</th>
      <th>Ribf2Ac</th>
      <th>Ribf3Ac</th>
      <th>Ribf5Ac</th>
      <th>Ribf5P</th>
      <th>RibfOAc</th>
      <th>Sed</th>
      <th>Sedf</th>
      <th>Sia</th>
      <th>Sor</th>
      <th>Sorf</th>
      <th>Suc</th>
      <th>Sug</th>
      <th>Sug2Ac</th>
      <th>Sug2Ac3Ac</th>
      <th>Sug2Ac3Ac4Ac</th>
      <th>Sug2Ac5Me</th>
      <th>Sug5Ac7Pyr</th>
      <th>Sug5Ac7Pyr8Ac</th>
      <th>SugOAc</th>
      <th>Sugf</th>
      <th>Tag</th>
      <th>Tagf</th>
      <th>Tal</th>
      <th>TalA</th>
      <th>TalNAc-ol</th>
      <th>Thre-ol</th>
      <th>Thre-onic</th>
      <th>Tyv</th>
      <th>Tyv1PP</th>
      <th>Tyv2Me</th>
      <th>VioNAc</th>
      <th>Xluf</th>
      <th>Xluf1Me</th>
      <th>Xluf3Me</th>
      <th>XlufOMe</th>
      <th>Xyl</th>
      <th>Xyl-ol</th>
      <th>Xyl-onic</th>
      <th>Xyl1Me</th>
      <th>Xyl1N</th>
      <th>Xyl1N-ol</th>
      <th>Xyl1N2Me-ol</th>
      <th>Xyl1P</th>
      <th>Xyl1PP</th>
      <th>Xyl2Ac</th>
      <th>Xyl2Ac3Ac</th>
      <th>Xyl2Ac3Ac4Ac</th>
      <th>Xyl2F</th>
      <th>Xyl2Me</th>
      <th>Xyl2Me3Me</th>
      <th>Xyl2Me4Me</th>
      <th>Xyl2NAc</th>
      <th>Xyl2P</th>
      <th>Xyl2P-ol</th>
      <th>Xyl2S</th>
      <th>Xyl3Ac</th>
      <th>Xyl3Me</th>
      <th>Xyl4Ac</th>
      <th>Xyl4Me</th>
      <th>Xyl4N</th>
      <th>Xyl4S</th>
      <th>XylOAc</th>
      <th>XylOBz</th>
      <th>XylOMe</th>
      <th>Xylf</th>
      <th>Xylf2Me3Me5Me</th>
      <th>Yer</th>
      <th>YerOAc</th>
      <th>a1-1</th>
      <th>a1-11</th>
      <th>a1-2</th>
      <th>a1-3</th>
      <th>a1-4</th>
      <th>a1-5</th>
      <th>a1-6</th>
      <th>a1-7</th>
      <th>a1-8</th>
      <th>a1-9</th>
      <th>a1-?</th>
      <th>a2-1</th>
      <th>a2-11</th>
      <th>a2-2</th>
      <th>a2-3</th>
      <th>a2-4</th>
      <th>a2-5</th>
      <th>a2-6</th>
      <th>a2-7</th>
      <th>a2-8</th>
      <th>a2-9</th>
      <th>a2-?</th>
      <th>a3-2</th>
      <th>a3-4</th>
      <th>a4-1</th>
      <th>a6-1</th>
      <th>a6-2</th>
      <th>a6-3</th>
      <th>a6-6</th>
      <th>b1-1</th>
      <th>b1-2</th>
      <th>b1-3</th>
      <th>b1-4</th>
      <th>b1-5</th>
      <th>b1-6</th>
      <th>b1-7</th>
      <th>b1-8</th>
      <th>b1-9</th>
      <th>b1-?</th>
      <th>b2-1</th>
      <th>b2-2</th>
      <th>b2-3</th>
      <th>b2-4</th>
      <th>b2-5</th>
      <th>b2-6</th>
      <th>b2-7</th>
      <th>b2-8</th>
      <th>b3-1</th>
      <th>b3-3</th>
      <th>b4-1</th>
      <th>b4-2</th>
      <th>b6-1</th>
      <th>b6-2</th>
      <th>b6-3</th>
      <th>bond</th>
      <th>dHex</th>
      <th>{Fuc</th>
      <th>{Gal</th>
      <th>{GlcNAc</th>
      <th>{HexNAc</th>
      <th>{Man</th>
      <th>{Neu5Ac</th>
      <th>{Neu5Gc</th>
      <th>}Fuc</th>
      <th>}Gal</th>
      <th>}GlcNAc</th>
      <th>}Man</th>
      <th>}Neu5Ac</th>
      <th>}Neu5Gc</th>
      <th>}{Fuc</th>
      <th>}{Gal</th>
      <th>}{GlcNAc</th>
      <th>}{Man</th>
      <th>}{Neu5Ac</th>
      <th>}{Neu5Gc</th>
      <th>Fuc(a1-3)GlcNAc</th>
      <th>GalNAc(a1-4)GlcNAcA</th>
      <th>GlcN(b1-7)Kdo</th>
      <th>GlcN4P(b1-6)GlcN1P</th>
      <th>GlcNAc(b1-4)GlcNAc</th>
      <th>GlcNAcA(a1-4)Kdo</th>
      <th>Kdo(a2-4)Kdo</th>
      <th>Kdo(a2-5)Kdo</th>
      <th>Kdo(a2-6)GlcN4P</th>
      <th>Man(a1-2)Man</th>
      <th>Man(a1-3)Man</th>
      <th>Man(a1-6)Man</th>
      <th>Man(b1-4)GlcNAc</th>
      <th>Xyl(b1-2)Man</th>
    </tr>
  </thead>
  <tbody>
    <tr>
      <th>Man(a1-3)[Man(a1-6)][Xyl(b1-2)]Man(b1-4)GlcNAc(b1-4)[Fuc(a1-3)]GlcNAc</th>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>1</td>
      <td>1</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>1</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>8.0</td>
      <td>1.0</td>
      <td>4.0</td>
      <td>1.846154</td>
      <td>0.591716</td>
      <td>4.0</td>
      <td>1.0</td>
      <td>4.0</td>
      <td>4.0</td>
      <td>-3.448276e-02</td>
      <td>0.240093</td>
      <td>0.051241</td>
      <td>0.727273</td>
      <td>0.337083</td>
      <td>0.251423</td>
      <td>0.276471</td>
      <td>0.000487</td>
      <td>0.400000</td>
      <td>0.181818</td>
      <td>0.288591</td>
      <td>0.003994</td>
      <td>0.727273</td>
      <td>0.240093</td>
      <td>0.051241</td>
      <td>0.318182</td>
      <td>0.090909</td>
      <td>0.179293</td>
      <td>0.006460</td>
      <td>0.727273</td>
      <td>0.240093</td>
      <td>0.051241</td>
      <td>6.950000</td>
      <td>3.253571</td>
      <td>4.820330</td>
      <td>0.908780</td>
      <td>66.603303</td>
      <td>26.305893</td>
      <td>44.589784</td>
      <td>127.751200</td>
      <td>4.0</td>
      <td>13.0</td>
      <td>13.0</td>
      <td>0.057103</td>
      <td>-2.075921</td>
      <td>13.0</td>
      <td>12.0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>1</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>2</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>3</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>1</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>2</td>
      <td>0</td>
      <td>0</td>
      <td>1</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>1</td>
      <td>0</td>
      <td>2</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>1</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>1</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>1</td>
      <td>1</td>
      <td>1</td>
      <td>1</td>
    </tr>
    <tr>
      <th>Man(a1-2)Man(a1-2)Man(a1-3)[Man(a1-3)Man(a1-6)]Man(b1-4)GlcNAc(b1-4)GlcNAc</th>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>1</td>
      <td>1</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>10.0</td>
      <td>1.0</td>
      <td>3.0</td>
      <td>1.866667</td>
      <td>0.248889</td>
      <td>3.0</td>
      <td>0.0</td>
      <td>3.0</td>
      <td>3.0</td>
      <td>-2.331468e-15</td>
      <td>0.263004</td>
      <td>0.037282</td>
      <td>0.703297</td>
      <td>0.288267</td>
      <td>0.234925</td>
      <td>0.257853</td>
      <td>0.000179</td>
      <td>0.341463</td>
      <td>0.157303</td>
      <td>0.238951</td>
      <td>0.003059</td>
      <td>0.703297</td>
      <td>0.263004</td>
      <td>0.037282</td>
      <td>0.296703</td>
      <td>0.076923</td>
      <td>0.182104</td>
      <td>0.005067</td>
      <td>0.703297</td>
      <td>0.263004</td>
      <td>0.037282</td>
      <td>6.616667</td>
      <td>3.407937</td>
      <td>4.921958</td>
      <td>0.799295</td>
      <td>70.823725</td>
      <td>26.381812</td>
      <td>48.985176</td>
      <td>174.452553</td>
      <td>3.0</td>
      <td>15.0</td>
      <td>15.0</td>
      <td>0.031066</td>
      <td>-2.658737</td>
      <td>15.0</td>
      <td>14.0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>2</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>6</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>2</td>
      <td>2</td>
      <td>0</td>
      <td>0</td>
      <td>1</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>2</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>1</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>1</td>
      <td>1</td>
      <td>1</td>
      <td>1</td>
      <td>0</td>
    </tr>
    <tr>
      <th>GalNAc(a1-4)GlcNAcA(a1-4)[GlcN(b1-7)]Kdo(a2-5)[Kdo(a2-4)]Kdo(a2-6)GlcN4P(b1-6)GlcN1P</th>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>10.0</td>
      <td>2.0</td>
      <td>4.0</td>
      <td>1.866667</td>
      <td>0.382222</td>
      <td>3.0</td>
      <td>0.0</td>
      <td>4.0</td>
      <td>4.0</td>
      <td>-1.449275e-02</td>
      <td>0.239560</td>
      <td>0.044684</td>
      <td>0.615385</td>
      <td>0.287575</td>
      <td>0.234359</td>
      <td>0.257668</td>
      <td>0.000274</td>
      <td>0.350000</td>
      <td>0.172840</td>
      <td>0.255611</td>
      <td>0.003247</td>
      <td>0.615385</td>
      <td>0.239560</td>
      <td>0.044684</td>
      <td>0.307692</td>
      <td>0.076923</td>
      <td>0.169545</td>
      <td>0.006240</td>
      <td>0.615385</td>
      <td>0.239560</td>
      <td>0.044684</td>
      <td>6.616667</td>
      <td>3.563492</td>
      <td>5.083122</td>
      <td>0.950051</td>
      <td>66.992537</td>
      <td>28.248894</td>
      <td>47.236515</td>
      <td>150.711681</td>
      <td>4.0</td>
      <td>15.0</td>
      <td>15.0</td>
      <td>0.013600</td>
      <td>-2.688625</td>
      <td>15.0</td>
      <td>14.0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>1</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>1</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>1</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>1</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>1</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>3</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>2</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>1</td>
      <td>1</td>
      <td>1</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>1</td>
      <td>1</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>1</td>
      <td>1</td>
      <td>1</td>
      <td>0</td>
      <td>1</td>
      <td>1</td>
      <td>1</td>
      <td>1</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
      <td>0</td>
    </tr>
  </tbody>
</table>

``` python
#using graphs, you can easily check whether two glycans are the same - even if they use different bracket notations!
from glycowork.motif.graph import compare_glycans
print(compare_glycans('Man(a1-3)[Man(a1-6)]Man(b1-4)GlcNAc(b1-4)[Fuc(a1-6)]GlcNAc',
                     'Man(a1-6)[Man(a1-3)]Man(b1-4)GlcNAc(b1-4)[Fuc(a1-6)]GlcNAc'))
print(compare_glycans('Man(a1-3)[Man(a1-6)]Man(b1-4)GlcNAc(b1-4)[Fuc(a1-6)]GlcNAc',
                     'Man(a1-6)[Man(a1-3)]Man(b1-4)GlcNAc(b1-4)GlcNAc'))

#or you could find the terminal structures of a glycan
from glycowork.motif.annotate import get_terminal_structures
print("\nTerminal structures:")
print(get_terminal_structures('Man(a1-3)[Man(a1-6)]Man(b1-4)GlcNAc(b1-4)[Fuc(a1-6)]GlcNAc'))
```

    True
    False

    Terminal structures:
    ['Man(a1-3)', 'Man(a1-6)', 'Fuc(a1-6)']

``` python
#given a composition, find matching glycan structures in sugarbase; can be set to species-specific structures
from glycowork.motif.tokenization import compositions_to_structures
print(compositions_to_structures([{'Hex':3, 'HexNAc':4}], reducing_end = 'GlcNAc'))

#or we could calculate the mass of this composition
from glycowork.motif.tokenization import composition_to_mass
print("\nMass of the composition Hex3HexNAc4")
print(composition_to_mass({'Hex':3, 'HexNAc':4}))
```

    0 compositions could not be matched. Run with verbose = True to see which compositions.
                                                  glycan  abundance
    0  GalNAc(b1-4)GlcNAc(b1-2)Man(a1-3)[Man(a1-6)]Ma...          0
    1  GlcNAc(?1-?)Man(a1-3)[GlcNAc(?1-?)Man(a1-6)]Ma...          0
    2  GlcNAc(b1-2)Man(a1-3)[GlcNAc(b1-6)Man(a1-6)]Ma...          0
    3  GlcNAc(b1-4)Man(a1-3)[GlcNAc(b1-6)Man(a1-6)]Ma...          0
    4  GlcNAc(b1-2)Man(a1-3)[GlcNAc(b1-2)Man(a1-6)]Ma...          0
    5  GlcNAc(b1-2)Man(a1-3)[GlcNAc(b1-2)Man(a1-6)][G...          0
    6  GlcNAc(b1-2)Man(a1-3)[GlcNAc(b1-2)[GlcNAc(b1-4...          0
    7  GlcNAc(b1-2)[GlcNAc(b1-4)]Man(a1-3)[GlcNAc(b1-...          0
    8  GlcNAc(b1-2)Man(a1-3)[GlcNAc(b1-4)][Man(a1-6)]...          0
    9  GlcNAc(b1-4)Man(a1-3)[GlcNAc(b1-2)Man(a1-6)]Ma...          0

    Mass of the composition Hex3HexNAc4
    1316.4865545999999
